@@ -1,33 +1,56 @@
 #!/usr/bin/php
 <?php
-if(!defined('DOKU_INC')) define('DOKU_INC', realpath(dirname(__FILE__).'/../').'/');
+
+use splitbrain\phpcli\CLI;
+use splitbrain\phpcli\Options;
+
+if(!defined('DOKU_INC')) define('DOKU_INC', realpath(dirname(__FILE__) . '/../') . '/');
 define('NOSESSION', 1);
-require_once(DOKU_INC.'inc/init.php');
+require_once(DOKU_INC . 'inc/init.php');
 
 /**
  * Find wanted pages
  */
-class WantedPagesCLI extends DokuCLI {
+class WantedPagesCLI extends CLI {
 
     const DIR_CONTINUE = 1;
-    const DIR_NS       = 2;
-    const DIR_PAGE     = 3;
+    const DIR_NS = 2;
+    const DIR_PAGE = 3;
+
+    private $skip = false;
+    private $sort = 'wanted';
+
+    private $result = array();
 
     /**
      * Register options and arguments on the given $options object
      *
-     * @param DokuCLI_Options $options
+     * @param Options $options
      * @return void
      */
-    protected function setup(DokuCLI_Options $options) {
+    protected function setup(Options $options) {
         $options->setHelp(
-            'Outputs a list of wanted pages (pages which have internal links but do not yet exist).'
+            'Outputs a list of wanted pages (pages that do not exist yet) and their origin pages ' .
+            ' (the pages that are linkin to these missing pages).'
         );
         $options->registerArgument(
             'namespace',
             'The namespace to lookup. Defaults to root namespace',
             false
         );
+
+        $options->registerOption(
+            'sort',
+            'Sort by wanted or origin page',
+            's',
+            '(wanted|origin)'
+        );
+
+        $options->registerOption(
+            'skip',
+            'Do not show the second dimension',
+            'k'
+        );
     }
 
     /**
@@ -35,29 +58,36 @@ class WantedPagesCLI extends DokuCLI {
      *
      * Arguments and options have been parsed when this is run
      *
-     * @param DokuCLI_Options $options
+     * @param Options $options
      * @return void
      */
-    protected function main(DokuCLI_Options $options) {
-
-        if($options->args) {
-            $startdir = dirname(wikiFN($options->args[0].':xxx'));
+    protected function main(Options $options) {
+        $args = $options->getArgs();
+        if($args) {
+            $startdir = dirname(wikiFN($args[0] . ':xxx'));
         } else {
             $startdir = dirname(wikiFN('xxx'));
         }
 
+        $this->skip = $options->getOpt('skip');
+        $this->sort = $options->getOpt('sort');
+
         $this->info("searching $startdir");
 
-        $wanted_pages = array();
-
         foreach($this->get_pages($startdir) as $page) {
-            $wanted_pages = array_merge($wanted_pages, $this->internal_links($page));
+            $this->internal_links($page);
         }
-        $wanted_pages = array_unique($wanted_pages);
-        sort($wanted_pages);
-
-        foreach($wanted_pages as $page) {
-            print $page."\n";
+        ksort($this->result);
+        foreach($this->result as $main => $subs) {
+            if($this->skip) {
+                print "$main\n";
+            } else {
+                $subs = array_unique($subs);
+                sort($subs);
+                foreach($subs as $sub) {
+                    printf("%-40s %s\n", $main, $sub);
+                }
+            }
         }
     }
 
@@ -72,7 +102,7 @@ class WantedPagesCLI extends DokuCLI {
         if($entry == '.' || $entry == '..') {
             return WantedPagesCLI::DIR_CONTINUE;
         }
-        if(is_dir($basepath.'/'.$entry)) {
+        if(is_dir($basepath . '/' . $entry)) {
             if(strpos($entry, '_') === 0) {
                 return WantedPagesCLI::DIR_CONTINUE;
             }
@@ -95,7 +125,7 @@ class WantedPagesCLI extends DokuCLI {
         static $trunclen = null;
         if(!$trunclen) {
             global $conf;
-            $trunclen = strlen($conf['datadir'].':');
+            $trunclen = strlen($conf['datadir'] . ':');
         }
 
         if(!is_dir($dir)) {
@@ -103,17 +133,17 @@ class WantedPagesCLI extends DokuCLI {
         }
 
         $pages = array();
-        $dh    = opendir($dir);
+        $dh = opendir($dir);
         while(false !== ($entry = readdir($dh))) {
             $status = $this->dir_filter($entry, $dir);
             if($status == WantedPagesCLI::DIR_CONTINUE) {
                 continue;
             } else if($status == WantedPagesCLI::DIR_NS) {
-                $pages = array_merge($pages, $this->get_pages($dir.'/'.$entry));
+                $pages = array_merge($pages, $this->get_pages($dir . '/' . $entry));
             } else {
-                $page    = array(
-                    'id'   => pathID(substr($dir.'/'.$entry, $trunclen)),
-                    'file' => $dir.'/'.$entry,
+                $page = array(
+                    'id' => pathID(substr($dir . '/' . $entry, $trunclen)),
+                    'file' => $dir . '/' . $entry,
                 );
                 $pages[] = $page;
             }
@@ -123,31 +153,34 @@ class WantedPagesCLI extends DokuCLI {
     }
 
     /**
-     * Parse instructions and returns the non-existing links
+     * Parse instructions and add the non-existing links to the result array
      *
      * @param array $page array with page id and file path
-     * @return array
      */
     function internal_links($page) {
         global $conf;
         $instructions = p_get_instructions(file_get_contents($page['file']));
-        $links        = array();
-        $cns          = getNS($page['id']);
-        $exists       = false;
+        $cns = getNS($page['id']);
+        $exists = false;
+        $pid = $page['id'];
         foreach($instructions as $ins) {
             if($ins[0] == 'internallink' || ($conf['camelcase'] && $ins[0] == 'camelcaselink')) {
                 $mid = $ins[1][0];
                 resolve_pageid($cns, $mid, $exists);
                 if(!$exists) {
-                    list($mid) = explode('#', $mid); //record pages without hashs
-                    $links[] = $mid;
+                    list($mid) = explode('#', $mid); //record pages without hashes
+
+                    if($this->sort == 'origin') {
+                        $this->result[$pid][] = $mid;
+                    } else {
+                        $this->result[$mid][] = $pid;
+                    }
                 }
             }
         }
-        return $links;
     }
 }
 
 // Main
 $cli = new WantedPagesCLI();
-$cli->run();
\ No newline at end of file
+$cli->run();
