@@ -28,7 +28,7 @@ class ButtonElement extends Element {
      * @return string
      */
     public function toHTML() {
-        return '<button ' . buildAttributes($this->attrs()) . '>'.$this->content.'</button>';
+        return '<button ' . buildAttributes($this->attrs(), true) . '>'.$this->content.'</button>';
     }
 
 }
