@@ -2,7 +2,8 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Domingo Redal <docxml@gmail.com>
  * @author Zigor Astarbe <zigor@astarbe.com>
  * @author Adrián Ariza <adrian_ariza.ciudad.com.ar>
  * @author Gabiel Molina <gabriel191@gmail.com>
@@ -11,7 +12,7 @@
  * @author Miguel Pagano <miguel.pagano@gmail.com>
  * @author Oscar M. Lage <r0sk10@gmail.com>
  * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
- * @author oliver@samera.com.py
+ * @author oliver <oliver@samera.com.py>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Manuel Meco <manuel.meco@gmail.com>
  * @author Jordan Mero <hack.jord@gmail.com>
@@ -27,10 +28,22 @@
  * @author Oscar Ciudad <oscar@jacho.net>
  * @author Ruben Figols <ruben.figols@gmail.com>
  * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
- * @author Mercè López mercelz@gmail.com
- * @author r0sk <r0sk10@gmail.com>
+ * @author Mercè López <mercelz@gmail.com>
  * @author monica <may.dorado@gmail.com>
  * @author Antonio Bueno <atnbueno@gmail.com>
+ * @author Juan De La Cruz <juann.dlc@gmail.com>
+ * @author Fernando <fdiezala@gmail.com>
+ * @author Eloy <ej.perezgomez@gmail.com>
+ * @author Antonio Castilla <antoniocastilla@trazoide.com>
+ * @author Jonathan Hernández <me@jhalicea.com>
+ * @author pokesakura <pokesakura@gmail.com>
+ * @author Álvaro Iradier <airadier@gmail.com>
+ * @author Alejandro Nunez <nunez.alejandro@gmail.com>
+ * @author Mauricio Segura <maose38@yahoo.es>
+ * @author solohazlo <solohhazlo@gmail.com>
+ * @author Romano <romanocl@outlook.com>
+ * @author David Roy <davidroyapp@gmail.com>
+ * @author Enny Rodriguez <aquilez.4@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,13 +53,13 @@ $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Editar esta página';
-$lang['btn_source']            = 'Ver fuente';
+$lang['btn_source']            = 'Ver la fuente de esta página';
 $lang['btn_show']              = 'Ver página';
 $lang['btn_create']            = 'Crear esta página';
 $lang['btn_search']            = 'Buscar';
 $lang['btn_save']              = 'Guardar';
 $lang['btn_preview']           = 'Previsualización';
-$lang['btn_top']               = 'Ir hasta arriba';
+$lang['btn_top']               = 'Volver arriba';
 $lang['btn_newer']             = '<< más reciente';
 $lang['btn_older']             = 'menos reciente >>';
 $lang['btn_revs']              = 'Revisiones antiguas';
@@ -62,7 +75,6 @@ $lang['btn_update']            = 'Actualizar';
 $lang['btn_delete']            = 'Borrar';
 $lang['btn_back']              = 'Atrás';
 $lang['btn_backlink']          = 'Enlaces a esta página';
-$lang['btn_backtomedia']       = 'Volver a la selección de archivos multimedia';
 $lang['btn_subscribe']         = 'Suscribirse a cambios de la página';
 $lang['btn_profile']           = 'Actualizar perfil';
 $lang['btn_reset']             = 'Restablecer';
@@ -73,9 +85,11 @@ $lang['btn_draftdel']          = 'Eliminar borrador';
 $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Registrarse';
 $lang['btn_apply']             = 'Aplicar';
-$lang['btn_media']             = 'Gestor de ficheros';
+$lang['btn_media']             = 'Administrador de Ficheros';
 $lang['btn_deleteuser']        = 'Elimina Mi Cuenta';
-$lang['loggedinas']            = 'Conectado como ';
+$lang['btn_img_backto']        = 'Volver a %s';
+$lang['btn_mediaManager']      = 'Ver en el administrador de ficheros';
+$lang['loggedinas']            = 'Conectado como:';
 $lang['user']                  = 'Usuario';
 $lang['pass']                  = 'Contraseña';
 $lang['newpass']               = 'Nueva contraseña';
@@ -90,42 +104,9 @@ $lang['badpassconfirm']        = 'Lo siento, la contraseña es errónea';
 $lang['minoredit']             = 'Cambios menores';
 $lang['draftdate']             = 'Borrador guardado automáticamente:';
 $lang['nosecedit']             = 'La página ha cambiado en el lapso, la información de sección estaba anticuada, en su lugar se cargó la página completa.';
-$lang['regmissing']            = 'Lo siento, tienes que completar todos los campos.';
-$lang['reguexists']            = 'Lo siento, ya existe un usuario con este nombre.';
-$lang['regsuccess']            = 'El usuario ha sido creado y la contraseña se ha enviado por correo.';
-$lang['regsuccess2']           = 'El usuario ha sido creado.';
-$lang['regmailfail']           = 'Parece que ha habido un error al enviar el correo con la contraseña. ¡Por favor, contacta al administrador!';
-$lang['regbadmail']            = 'La dirección de correo no parece válida. Si piensas que esto es un error, contacta al administrador';
-$lang['regbadpass']            = 'Las dos contraseñas no son iguales, por favor inténtalo de nuevo.';
-$lang['regpwmail']             = 'Tu contraseña de DokuWiki';
-$lang['reghere']               = '¿No tienes una cuenta todavía? Consigue una';
-$lang['profna']                = 'Este wiki no permite la modificación del perfil';
-$lang['profnochange']          = 'Sin cambios, nada que hacer.';
-$lang['profnoempty']           = 'No se permite que el nombre o la dirección de correo electrónico estén vacíos.';
-$lang['profchanged']           = 'Se actualizó correctamente el perfil del usuario.';
-$lang['profnodelete']          = 'Este wiki no soporta el borrado de usuarios';
-$lang['profdeleteuser']        = 'Eliminar Cuenta';
-$lang['profdeleted']           = 'Tu cuenta de usuario ha sido eliminada de este wiki';
-$lang['profconfdelete']        = 'Deseo eliminar mi cuenta de este wiki. <br /> Esta acción es irreversible.';
-$lang['profconfdeletemissing'] = 'Casilla de verificación no activada.';
-$lang['pwdforget']             = '¿Has olvidado tu contraseña? Consigue una nueva';
-$lang['resendna']              = 'Este wiki no brinda la posibilidad de reenvío de contraseña.';
-$lang['resendpwd']             = 'Establecer nueva contraseña para';
-$lang['resendpwdmissing']      = 'Lo siento, debes completar todos los campos.';
-$lang['resendpwdnouser']       = 'Lo siento, no se encuentra este usuario en nuestra base de datos.';
-$lang['resendpwdbadauth']      = 'Lo siento, este código de autenticación no es válido. Asegúrate de haber usado el enlace de confirmación entero.';
-$lang['resendpwdconfirm']      = 'Un enlace para confirmación ha sido enviado por correo electrónico.';
-$lang['resendpwdsuccess']      = 'Tu nueva contraseña ha sido enviada por correo electrónico.';
-$lang['license']               = 'Excepto donde se indique lo contrario, el contenido de esta wiki se autoriza bajo la siguiente licencia:';
-$lang['licenseok']             = 'Nota: Al editar esta página, estás de acuerdo en autorizar su contenido bajo la siguiente licencia:';
-$lang['searchmedia']           = 'Buscar archivo:';
-$lang['searchmedia_in']        = 'Buscar en %s';
-$lang['txt_upload']            = 'Selecciona el archivo a subir';
-$lang['txt_filename']          = 'Subir como (opcional)';
-$lang['txt_overwrt']           = 'Sobreescribir archivo existente';
-$lang['maxuploadsize']         = 'Peso máximo de %s por archivo';
-$lang['lockedby']              = 'Actualmente bloqueado por';
-$lang['lockexpire']            = 'El bloqueo expira en';
+$lang['searchcreatepage']      = 'Si no encontró lo que estaba buscando, puede crear o editar la página %s, nombrada después de su consulta.';
+$lang['search_fullresults']    = 'Resultados de texto completo';
+$lang['js']['search_toggle_tools'] = 'Alternar herramientas de búsqueda';
 $lang['js']['willexpire']      = 'El bloqueo para la edición de esta página expira en un minuto.\nPAra prevenir conflictos uso el botón Previsualizar para restaurar el contador de bloqueo.';
 $lang['js']['notsavedyet']     = 'Los cambios que no se han guardado se perderán.
 ¿Realmente quieres continuar?';
@@ -169,10 +150,59 @@ $lang['js']['media_done_btn']  = 'Hecho';
 $lang['js']['media_drop']      = 'Arrastra los ficheros aquí para cargar';
 $lang['js']['media_cancel']    = 'Eliminar';
 $lang['js']['media_overwrt']   = 'Sobreescribir ficheros exitentes';
+$lang['search_exact_match']    = 'Coincidencia exacta';
+$lang['search_starts_with']    = 'Comienza con';
+$lang['search_ends_with']      = 'Termina con';
+$lang['search_contains']       = 'Contiene';
+$lang['search_custom_match']   = 'Personalizado';
+$lang['search_any_ns']         = 'Cualquier espacio de nombres';
+$lang['search_any_time']       = 'En cualquier momento';
+$lang['search_past_7_days']    = 'La semana pasada';
+$lang['search_past_month']     = 'El mes pasado';
+$lang['search_past_year']      = 'El año pasado';
+$lang['search_sort_by_hits']   = 'Ordenar por relevancia';
+$lang['search_sort_by_mtime']  = 'Ordenar por la última modificación';
+$lang['regmissing']            = 'Lo siento, tienes que completar todos los campos.';
+$lang['reguexists']            = 'Lo siento, ya existe un usuario con este nombre.';
+$lang['regsuccess']            = 'El usuario ha sido creado y la contraseña se ha enviado por correo.';
+$lang['regsuccess2']           = 'El usuario ha sido creado.';
+$lang['regfail']               = 'No se pudo crear el usuario.';
+$lang['regmailfail']           = 'Parece que ha habido un error al enviar el correo con la contraseña. ¡Por favor, contacta al administrador!';
+$lang['regbadmail']            = 'La dirección de correo no parece válida. Si piensas que esto es un error, contacta al administrador';
+$lang['regbadpass']            = 'Las dos contraseñas no son iguales, por favor inténtalo de nuevo.';
+$lang['regpwmail']             = 'Tu contraseña de DokuWiki';
+$lang['reghere']               = '¿No tienes una cuenta todavía? Consigue una';
+$lang['profna']                = 'Este wiki no permite la modificación del perfil';
+$lang['profnochange']          = 'Sin cambios, nada que hacer.';
+$lang['profnoempty']           = 'No se permite que el nombre o la dirección de correo electrónico estén vacíos.';
+$lang['profchanged']           = 'Se actualizó correctamente el perfil del usuario.';
+$lang['profnodelete']          = 'Este wiki no soporta el borrado de usuarios';
+$lang['profdeleteuser']        = 'Eliminar Cuenta';
+$lang['profdeleted']           = 'Tu cuenta de usuario ha sido eliminada de este wiki';
+$lang['profconfdelete']        = 'Deseo eliminar mi cuenta de este wiki. <br /> Esta acción es irreversible.';
+$lang['profconfdeletemissing'] = 'Casilla de verificación no activada.';
+$lang['proffail']              = 'No se ha actualizado el perfil del usuario.';
+$lang['pwdforget']             = '¿Has olvidado tu contraseña? Consigue una nueva';
+$lang['resendna']              = 'Este wiki no brinda la posibilidad de reenvío de contraseña.';
+$lang['resendpwd']             = 'Establecer nueva contraseña para';
+$lang['resendpwdmissing']      = 'Lo siento, debes completar todos los campos.';
+$lang['resendpwdnouser']       = 'Lo siento, no se encuentra este usuario en nuestra base de datos.';
+$lang['resendpwdbadauth']      = 'Lo siento, este código de autenticación no es válido. Asegúrate de haber usado el enlace de confirmación entero.';
+$lang['resendpwdconfirm']      = 'Un enlace para confirmación ha sido enviado por correo electrónico.';
+$lang['resendpwdsuccess']      = 'Tu nueva contraseña ha sido enviada por correo electrónico.';
+$lang['license']               = 'Excepto donde se indique lo contrario, el contenido de este wiki esta bajo la siguiente licencia:';
+$lang['licenseok']             = 'Nota: Al editar esta página, estás de acuerdo en autorizar su contenido bajo la siguiente licencia:';
+$lang['searchmedia']           = 'Buscar archivo:';
+$lang['searchmedia_in']        = 'Buscar en %s';
+$lang['txt_upload']            = 'Selecciona el archivo a subir:';
+$lang['txt_filename']          = 'Subir como (opcional):';
+$lang['txt_overwrt']           = 'Sobreescribir archivo existente';
+$lang['maxuploadsize']         = 'Peso máximo de %s por archivo';
+$lang['lockedby']              = 'Actualmente bloqueado por:';
+$lang['lockexpire']            = 'El bloqueo expira en:';
 $lang['rssfailed']             = 'Se ha producido un error mientras se leían los datos de este feed: ';
 $lang['nothingfound']          = 'No se ha encontrado nada.';
 $lang['mediaselect']           = 'Archivos Multimedia';
-$lang['fileupload']            = 'Subida de archivos multimedia';
 $lang['uploadsucc']            = 'El archivo se ha subido satisfactoriamente';
 $lang['uploadfail']            = 'La subida del fichero ha fallado. ¿Permisos equivocados?';
 $lang['uploadwrong']           = 'Subida de fichero denegada. ¡Los ficheros con esta extensión están prohibidos!';
@@ -206,10 +236,15 @@ $lang['difflink']              = 'Enlace a la vista de comparación';
 $lang['diff_type']             = 'Ver diferencias';
 $lang['diff_inline']           = 'En línea';
 $lang['diff_side']             = 'Lado a lado';
+$lang['diffprevrev']           = 'Revisión previa';
+$lang['diffnextrev']           = 'Próxima revisión';
+$lang['difflastrev']           = 'Última revisión';
+$lang['diffbothprevrev']       = 'Ambos lados, revisión anterior';
+$lang['diffbothnextrev']       = 'Ambos lados, revisión siguiente';
 $lang['line']                  = 'Línea';
-$lang['breadcrumb']            = 'Traza';
-$lang['youarehere']            = 'Estás aquí';
-$lang['lastmod']               = 'Última modificación';
+$lang['breadcrumb']            = 'Traza:';
+$lang['youarehere']            = 'Estás aquí:';
+$lang['lastmod']               = 'Última modificación:';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'borrado';
 $lang['created']               = 'creado';
@@ -258,24 +293,21 @@ $lang['qb_sig']                = 'Insertar firma';
 $lang['qb_smileys']            = 'Sonrisas';
 $lang['qb_chars']              = 'Caracteres especiales';
 $lang['upperns']               = 'Saltar al espacio de nombres superior';
-$lang['admin_register']        = 'Añadir nuevo usuario';
 $lang['metaedit']              = 'Editar metadatos';
 $lang['metasaveerr']           = 'La escritura de los metadatos ha fallado';
 $lang['metasaveok']            = 'Los metadatos han sido guardados';
-$lang['img_backto']            = 'Volver a';
-$lang['img_title']             = 'Título';
-$lang['img_caption']           = 'Epígrafe';
-$lang['img_date']              = 'Fecha';
-$lang['img_fname']             = 'Nombre de fichero';
-$lang['img_fsize']             = 'Tamaño';
-$lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Cámara';
-$lang['img_keywords']          = 'Palabras claves';
-$lang['img_width']             = 'Ancho';
-$lang['img_height']            = 'Alto';
-$lang['img_manager']           = 'Ver en el Administrador de medios';
+$lang['img_title']             = 'Título:';
+$lang['img_caption']           = 'Información: ';
+$lang['img_date']              = 'Fecha:';
+$lang['img_fname']             = 'Nombre del archivo:';
+$lang['img_fsize']             = 'Tamaño:';
+$lang['img_artist']            = 'Fotógrafo:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Cámara:';
+$lang['img_keywords']          = 'Palabras claves:';
+$lang['img_width']             = 'Ancho:';
+$lang['img_height']            = 'Alto:';
 $lang['subscr_subscribe_success'] = 'Se agregó %s a las listas de suscripción para %s';
 $lang['subscr_subscribe_error'] = 'Error al agregar %s a las listas de suscripción para %s';
 $lang['subscr_subscribe_noaddress'] = 'No hay dirección asociada con tu registro, no se puede agregarte a la lista de suscripción';
@@ -293,7 +325,6 @@ $lang['subscr_style_every']    = 'enviar correo en cada cambio';
 $lang['subscr_style_digest']   = 'Resumen de correo electrónico de cambios por cada página (cada %.2f días)';
 $lang['subscr_style_list']     = 'lista de páginas modificadas desde el último correo electrónico (cada %.2f días)';
 $lang['authtempfail']          = 'La autenticación de usuarios no está disponible temporalmente. Si esta situación persiste, por favor avisa al administrador del wiki.';
-$lang['authpwdexpire']         = 'Su contraseña caducara en %d días, debería cambiarla lo antes posible';
 $lang['i_chooselang']          = 'Elija su idioma';
 $lang['i_installer']           = 'Instalador de DokuWiki';
 $lang['i_wikiname']            = 'Nombre del wiki';
@@ -303,6 +334,7 @@ $lang['i_problems']            = 'El instalador encontró algunos problemas, se
 $lang['i_modified']            = 'Por razones de seguridad este script sólo funcionará con una instalación nueva y no modificada de Dokuwiki. Usted debe extraer nuevamente los ficheros del paquete bajado, o bien consultar las <a href="http://dokuwiki.org/install">instrucciones de instalación de Dokuwiki</a> completas.';
 $lang['i_funcna']              = 'La función de PHP <code>%s</code> no está disponible. ¿Tal vez su proveedor de hosting la ha deshabilitado por alguna razón?';
 $lang['i_phpver']              = 'Su versión de PHP <code>%s</code> es menor que la necesaria <code>%s</code>. Es necesario que actualice su instalación de PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload se debe deshabilitar en php.ini para que funcione DokuWiki.';
 $lang['i_permfail']            = 'DokuWili no puede escribir <code>%s</code>. ¡Es necesario establecer  correctamente los permisos de este directorio!';
 $lang['i_confexists']          = '<code>%s</code> ya existe';
 $lang['i_writeerr']            = 'Imposible crear <code>%s</code>. Se necesita que usted controle los permisos del fichero/directorio y que cree el fichero manualmente.';
@@ -321,13 +353,13 @@ $lang['i_license_none']        = 'No mostrar ninguna información sobre licencia
 $lang['i_pop_field']           = 'Por favor, ayúdanos a mejorar la experiencia de DokuWiki:';
 $lang['i_pop_label']           = 'Una vez al mes, enviar información anónima de uso de datos a los desarrolladores de DokuWiki';
 $lang['recent_global']         = 'Actualmente estás viendo los cambios dentro del namespace <b>%s</b>. También puedes <a href="%s">ver los cambios recientes en el wiki completo</a>.';
-$lang['years']                 = '%d años atrás';
-$lang['months']                = '%d meses atrás';
-$lang['weeks']                 = '%d semanas atrás';
-$lang['days']                  = '%d días atrás';
-$lang['hours']                 = '%d horas atrás';
-$lang['minutes']               = '%d minutos atrás';
-$lang['seconds']               = '%d segundos atrás';
+$lang['years']                 = 'hace %d años';
+$lang['months']                = 'hace %d meses';
+$lang['weeks']                 = 'hace %d semanas';
+$lang['days']                  = 'hace %d días';
+$lang['hours']                 = 'hace %d horas';
+$lang['minutes']               = 'hace %d minutos';
+$lang['seconds']               = 'hace %d segundos';
 $lang['wordblock']             = 'Sus cambios no se han guardado porque contienen textos bloqueados (spam).';
 $lang['media_uploadtab']       = 'Cargar';
 $lang['media_searchtab']       = 'Buscar';
@@ -352,7 +384,12 @@ $lang['media_perm_read']       = 'Disculpa, no tienes los permisos necesarios pa
 $lang['media_perm_upload']     = 'Disculpa, no tienes los permisos necesarios para cargar ficheros.';
 $lang['media_update']          = 'Actualizar nueva versión';
 $lang['media_restore']         = 'Restaurar esta versión';
+$lang['media_acl_warning']     = 'Puede que esta lista no esté completa debido a restricciones de la ACL y a las páginas ocultas.';
 $lang['currentns']             = 'Espacio de nombres actual';
 $lang['searchresult']          = 'Resultado de la búsqueda';
 $lang['plainhtml']             = 'HTML sencillo';
 $lang['wikimarkup']            = 'Etiquetado Wiki';
+$lang['page_nonexist_rev']     = 'La página no existía en %s. Por tanto fue creada en <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Incapaz de evaluar el parámetro "%s".';
+$lang['email_signature_text']  = 'Este mail ha sido generado por DokuWiki en
+@DOKUWIKIURL@';
