@@ -7,6 +7,7 @@
  * @author Inko Illarramendi <inko.i.a@gmail.com>
  * @author Zigor Astarbe <astarbe@gmail.com>
  * @author Yadav Gowda <yadav.gowda@gmail.com>
+ * @author Osoitz <oelkoro@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -63,14 +64,15 @@ $lang['fullname']              = 'Izen Deiturak';
 $lang['email']                 = 'E-Maila';
 $lang['profile']               = 'Erabiltzaile Profila';
 $lang['badlogin']              = 'Barkatu, prozesuak huts egin du; saiatu berriz';
+$lang['badpassconfirm']        = 'Pasahitz okerra';
 $lang['minoredit']             = 'Aldaketa Txikiak';
 $lang['draftdate']             = 'Zirriborroa automatikoki gorde da hemen:';
 $lang['nosecedit']             = 'Orria aldatua izan da bitartean, info atala zaharkituta geratu da, orri osoa kargatu da horren ordez.';
-$lang['searchcreatepage']      = 'Bilatzen zabiltzana aurkitu ez baduzu, zuk zeuk sortu dezakezu orri berri bat bilaketa ostean \'\'Sortu orri hau\'\' erabiliz.';
 $lang['regmissing']            = 'Barkatu, hutsune guztiak bete behar dituzu.';
 $lang['reguexists']            = 'Barkatu, izen bereko erabiltzailea existitzen da.';
 $lang['regsuccess']            = 'Erabiltzailea sortu da. Pasahitza mailez bidaliko zaizu.';
 $lang['regsuccess2']           = 'Erabiltzailea sortua izan da.';
+$lang['regfail']               = 'Ezin izan da erabiltzailea sortu';
 $lang['regmailfail']           = 'Badirudi arazoren bat egon dela pasahitza mailez bidaltzeko orduan. Administratzailearekin harremanetan jarri!';
 $lang['regbadmail']            = 'Emandako helbidea ez da zuzena - jarri harremanetan administratzailearekin hau akats bat dela uste baduzu';
 $lang['regbadpass']            = 'Idatzitako bi pasahitzak ez dira berdinak, berriz saiatu.';
@@ -80,7 +82,12 @@ $lang['profna']                = 'Wiki honek ez du profilaren aldaketa ahalbidet
 $lang['profnochange']          = 'Aldaketarik ez, ez dago egiteko ezer.';
 $lang['profnoempty']           = 'Izen edota e-posta hutsa ez dago onartua.';
 $lang['profchanged']           = 'Erabiltzaile profila arrakastaz eguneratua.';
+$lang['profnodelete']          = 'Wiki honek ez du erabiltzaileak ezabatzea onartzen';
 $lang['profdeleteuser']        = 'Kontua ezabatu';
+$lang['profdeleted']           = 'Zure erabiltzaile kontua wiki honetatik ezabatu da';
+$lang['profconfdelete']        = 'Nire kontua kendu nahi dut wiki honetatik. <br/>Ekintza hau ezin da desegin.';
+$lang['profconfdeletemissing'] = 'Ez da egiaztaketa-kutxa markatu';
+$lang['proffail']              = 'Erabiltzailearen perfila ez da eguneratu';
 $lang['pwdforget']             = 'Pasahitza ahaztu duzu? Eskuratu berri bat';
 $lang['resendna']              = 'Wiki honek ez du pasahitz berbidalketa onartzen.';
 $lang['resendpwd']             = '-entzat pasahitza berria ezarri';
@@ -96,6 +103,7 @@ $lang['searchmedia_in']        = 'Bilatu %s-n';
 $lang['txt_upload']            = 'Ireki nahi den fitxategia aukeratu:';
 $lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa):';
 $lang['txt_overwrt']           = 'Oraingo fitxategiaren gainean idatzi';
+$lang['maxuploadsize']         = 'Igo gehienez %s fitxategiko';
 $lang['lockedby']              = 'Momentu honetan blokeatzen:';
 $lang['lockexpire']            = 'Blokeaketa iraungitzen da:';
 $lang['js']['willexpire']      = 'Zure blokeaketa orri hau aldatzeko minutu batean iraungitzen da.\nGatazkak saihesteko, aurreikusi botoia erabili blokeaketa denboragailua berrabiarazteko.';
@@ -133,6 +141,7 @@ $lang['js']['del_confirm']     = 'Benetan ezabatu aukeratutako fitxategia(k)?';
 $lang['js']['restore_confirm'] = 'Benetan bertsio hau berrezarri?';
 $lang['js']['media_diff']      = 'Diferentziak ikusi:';
 $lang['js']['media_diff_both'] = 'Ondoz ondo';
+$lang['js']['media_diff_portions'] = 'Pasatu hatza';
 $lang['js']['media_select']    = 'Fitxategiak hautatu';
 $lang['js']['media_upload_btn'] = 'Igo';
 $lang['js']['media_done_btn']  = 'Egina';
@@ -175,6 +184,11 @@ $lang['difflink']              = 'Estekatu konparaketa bista honetara';
 $lang['diff_type']             = 'Ikusi diferentziak:';
 $lang['diff_inline']           = 'Lerro tartean';
 $lang['diff_side']             = 'Ondoz ondo';
+$lang['diffprevrev']           = 'Aurreko errebisioa';
+$lang['diffnextrev']           = 'Hurrengo errebisioa';
+$lang['difflastrev']           = 'Azken errebisioa';
+$lang['diffbothprevrev']       = 'Alde biak aurreko errebisioa';
+$lang['diffbothnextrev']       = 'Alde biak hurrengo errebisioa';
 $lang['line']                  = 'Marra';
 $lang['breadcrumb']            = 'Traza:';
 $lang['youarehere']            = 'Hemen zaude:';
@@ -279,8 +293,12 @@ $lang['i_policy']              = 'Hasierako ACL politika';
 $lang['i_pol0']                = 'Wiki Irekia (irakurri, idatzi, fitxategiak igo edonorentzat)';
 $lang['i_pol1']                = 'Wiki Publikoa (irakurri edonorentzat, idatzi eta fitxategiak igo erregistratutako erabiltzaileentzat)';
 $lang['i_pol2']                = 'Wiki Itxia (irakurri, idatzi, fitxategiak igo erregistratutako erabiltzaileentzat soilik)';
+$lang['i_allowreg']            = 'Baimendu erabiltzaileei bere burua erregistratzea';
 $lang['i_retry']               = 'Berriz saiatu';
 $lang['i_license']             = 'Mesedez, aukeratu zein lizentzipean ezarri nahi duzun zure edukia:';
+$lang['i_license_none']        = 'Ez erakutsi lizentzia informaziorik';
+$lang['i_pop_field']           = 'Lagundu gaitzazu Dokuwiki esperientzia hobetzen:';
+$lang['i_pop_label']           = 'Hilean behin bidali erabilera datu anonimoak Dokuwiki garatzaileei';
 $lang['recent_global']         = 'Une honetan <b>%s</b> izen-espazioaren barneko aldaketak ikusten ari zara.<a href="%s"> Wiki osoaren azken aldaketak</a> ere ikusi ditzakezu.';
 $lang['years']                 = 'duela %d urte';
 $lang['months']                = 'duela %d hilabete';
@@ -296,6 +314,8 @@ $lang['media_file']            = 'Fitxategia';
 $lang['media_viewtab']         = 'Begiratu';
 $lang['media_edittab']         = 'Editatu';
 $lang['media_historytab']      = 'Historia';
+$lang['media_list_thumbs']     = 'Iruditxoak';
+$lang['media_list_rows']       = 'Errenkadak';
 $lang['media_sort_name']       = 'Izena';
 $lang['media_sort_date']       = 'Data';
 $lang['media_files']           = '%s -n fitxategiak';
@@ -304,7 +324,16 @@ $lang['media_search']          = 'Bilatu %s -n';
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s -n %s';
 $lang['media_edit']            = '%s editatu';
+$lang['media_history']         = '%s(a)ren historiala';
+$lang['media_meta_edited']     = 'metadatuak editatua';
+$lang['media_perm_read']       = 'Ez duzu fitxategiak irakurtzeko behar beste baimen.';
+$lang['media_perm_upload']     = 'Ez duzu fitxategiak igotzeko behar beste baimen.';
 $lang['media_update']          = 'Bertsio berria igo';
 $lang['media_restore']         = 'Bertsio hau berrezarri';
-$lang['email_signature_text'] = 'Email hau DokuWiki erabiliz sortu da
+$lang['media_acl_warning']     = 'Hau agian ez dago osorik SCL murrizketak eta ezkutuko orriak direla eta.';
+$lang['searchresult']          = 'Bilaketaren emaitza';
+$lang['plainhtml']             = 'HTML hutsa';
+$lang['wikimarkup']            = 'Wiki kodea';
+$lang['page_nonexist_rev']     = 'Ez zegoen %s izeneko orririk. Sortu egin da <a href="%s">%s</a> helbidean.';
+$lang['email_signature_text']  = 'Email hau DokuWiki erabiliz sortu da
 @DOKUWIKIURL@';
