@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author behrad eslamifar <behrad_es@yahoo.com)
  * @author Mohsen Firoozmandan <info@mambolearn.com>
  * @author Omid Mottaghi <omidmr@gmail.com>
@@ -11,6 +11,13 @@
  * @author AmirH Hassaneini <mytechmix@gmail.com>
  * @author mehrdad <mehrdad.jafari.bojd@gmail.com>
  * @author reza_khn <reza_khn@yahoo.com>
+ * @author Hamid <zarrabi@sharif.edu>
+ * @author Mohamad Mehdi Habibi <habibi.esf@gmail.com>
+ * @author Mohammad Sadegh <msdn2013@gmail.com>
+ * @author Omid Hezaveh <hezpublic@gmail.com>
+ * @author Mohmmad Razavi <sepent@gmail.com>
+ * @author Masoud Sadrnezhaad <masoud@sadrnezhaad.ir>
+ * @author sam01 <m.sajad079@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -20,9 +27,9 @@ $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'ویرایش این صفحه';
-$lang['btn_source']            = 'نمایش مبدا';
+$lang['btn_source']            = 'نمایش کد صفحه';
 $lang['btn_show']              = 'نمایش صفحه';
-$lang['btn_create']            = 'ساخت این صفحه';
+$lang['btn_create']            = 'ایجاد این صفحه';
 $lang['btn_search']            = 'جستجو';
 $lang['btn_save']              = 'ذخیره';
 $lang['btn_preview']           = 'پیش‌نمایش';
@@ -38,78 +45,82 @@ $lang['btn_secedit']           = 'ویرایش';
 $lang['btn_login']             = 'ورود به سیستم';
 $lang['btn_logout']            = 'خروج از سیستم';
 $lang['btn_admin']             = 'مدیر';
-$lang['btn_update']            = 'به روز رسانی';
+$lang['btn_update']            = 'به‌روزرسانی';
 $lang['btn_delete']            = 'حذف';
 $lang['btn_back']              = 'عقب';
 $lang['btn_backlink']          = 'پیوندهای به این صفحه';
-$lang['btn_backtomedia']       = 'بازگشت به انتخاب فایل';
 $lang['btn_subscribe']         = 'عضویت در تغییرات صفحه';
-$lang['btn_profile']           = 'به روز رسانی پروفایل';
+$lang['btn_profile']           = 'به‌روزرسانی پروفایل';
 $lang['btn_reset']             = 'بازنشاندن';
-$lang['btn_resendpwd']         = 'تعیین کلمه عبور جدید';
+$lang['btn_resendpwd']         = 'تعیین گذرواژه‌ی جدید';
 $lang['btn_draft']             = 'ویرایش پیش‌نویس';
 $lang['btn_recover']           = 'بازیابی پیش‌نویس';
 $lang['btn_draftdel']          = 'حذف پیش‌نویس';
 $lang['btn_revert']            = 'بازیابی';
-$lang['btn_register']          = 'یک حساب جدید بسازید';
-$lang['btn_apply']             = 'اعمال کن';
-$lang['btn_media']             = 'مدیریت محتوای چند رسانه ای';
-$lang['btn_deleteuser']        = 'حذف حساب کاربری خود';
-$lang['loggedinas']            = 'به عنوان کاربر روبرو وارد شده‌اید:';
-$lang['user']                  = 'نام کاربری:';
-$lang['pass']                  = 'گذرواژه‌ی شما';
-$lang['newpass']               = 'گذروازه‌ی جدید';
-$lang['oldpass']               = 'گذرواژه‌ی پیشین';
-$lang['passchk']               = 'گذرواژه را دوباره وارد کنید';
-$lang['remember']              = 'گذرواژه را به یاد بسپار.';
-$lang['fullname']              = '*نام واقعی شما';
-$lang['email']                 = 'ایمیل شما*';
+$lang['btn_register']          = 'ثبت نام';
+$lang['btn_apply']             = 'اعمال';
+$lang['btn_media']             = 'مدیریت رسانه‌ها';
+$lang['btn_deleteuser']        = 'حساب کاربری مرا حذف کن';
+$lang['btn_img_backto']        = 'بازگشت به %s';
+$lang['btn_mediaManager']      = 'مشاهده در مدیریت رسانه‌ها';
+$lang['loggedinas']            = 'به این عنوان وارد شده‌اید:';
+$lang['user']                  = 'نام کاربری';
+$lang['pass']                  = 'گذرواژه‌';
+$lang['newpass']               = 'گذرواژه‌ی جدید';
+$lang['oldpass']               = 'گذرواژه‌ی فعلی را تایید کنید';
+$lang['passchk']               = 'یک بار دیگر';
+$lang['remember']              = 'مرا به خاطر بسپار';
+$lang['fullname']              = 'نام واقعی شما';
+$lang['email']                 = 'ایمیل';
 $lang['profile']               = 'پروفایل کاربر';
-$lang['badlogin']              = 'خطا در ورود به سیستم';
-$lang['badpassconfirm']        = 'متاسفم ، رمز عبور اشتباه است';
-$lang['minoredit']             = 'این ویرایش خُرد است';
-$lang['draftdate']             = 'ذخیره خودکار پیش‌نویس';
+$lang['badlogin']              = 'متاسفم، نام کاربری یا رمز عبور اشتباه است.';
+$lang['badpassconfirm']        = 'متاسفم، رمز عبور اشتباه است';
+$lang['minoredit']             = 'ویرایش‌های خُرد';
+$lang['draftdate']             = 'ذخیره خودکار پیش‌نویس در';
 $lang['nosecedit']             = 'این صفحه در این میان تغییر کرده است، اطلاعات بخش قدیمی شده است، در عوض محتوای کل نمایش داده می‌شود.';
 $lang['regmissing']            = 'متاسفم، شما باید همه قسمت‌ها را پر کنید.';
-$lang['reguexists']            = 'نام کاربری‌ای که وارد کردید قبلن استفاده شده است. خواهشمندیم یک نام دیگر انتخاب کنید.';
+$lang['reguexists']            = 'نام کاربری‌ای که وارد کردید قبلن استفاده شده است.';
 $lang['regsuccess']            = 'کاربر ساخته شد و گذرواژه به صورت ایمیل ارسال گردید.';
 $lang['regsuccess2']           = 'حساب ایجاد شد.';
-$lang['regmailfail']           = 'مشکلی در ارسال ایمیل پیش آمده است، با مدیر تماس بگیرید!';
-$lang['regbadmail']            = 'نشانی واردشده‌ی ایمیل قابل‌قبول نیست، چرا که دارای ساختار نامعتبری است. خواهشمندیم نشانی‌ای با ساختار صحیح وارد کنید و یا بخش مربوط را خالی بگذارید.';
-$lang['regbadpass']            = 'گذرواژه‌هایی که وارد کردید یکسان نیستند.';
+$lang['regfail']               = 'ایجاد کاربر ممکن نیست.';
+$lang['regmailfail']           = 'مشکلی در ارسال ایمیل رمز عبور پیش آمده است، با مدیر تماس بگیرید!';
+$lang['regbadmail']            = 'نشانی واردشدهٔ ایمیل قابل‌قبول نیست، چرا که دارای ساختار نامعتبری است. اگر فکر می‌کنید این یک ایراد سایت است با مدیر تماس بگیرید';
+$lang['regbadpass']            = 'گذرواژه‌هایی که وارد کردید یکسان نیستند، لطفاً یکبار دیگر تلاش کنید.';
 $lang['regpwmail']             = 'گذرواژه‌ی DokuWiki شما';
 $lang['reghere']               = 'شما هنوز حسابی در اینجا ندارید؟ یکی ایجاد کنید';
 $lang['profna']                = 'این ویکی اجازه ویرایش پروفایل را نمی‌دهد';
-$lang['profnochange']          = 'تغییری صورت نگرفت';
-$lang['profnoempty']           = 'نام و آدرس ایمیل باید پر شود';
-$lang['profchanged']           = 'پروفایل کاربر با موفقیت به روز شد';
-$lang['profnodelete']          = 'ویکی توانایی پشتیبانی از حذف کاربران را ندارد';
+$lang['profnochange']          = 'تغییری صورت نگرفت.';
+$lang['profnoempty']           = 'نام و آدرس ایمیل باید پر شود.';
+$lang['profchanged']           = 'پروفایل کاربر با موفقیت به روز شد.';
+$lang['profnodelete']          = 'این ویکی از حذف کاربران پشتیبانی نمی‌کند';
 $lang['profdeleteuser']        = 'حذف حساب کاربری';
-$lang['profdeleted']           = 'حساب کاربری شما حذف گردیده است.';
-$lang['pwdforget']             = 'گذرواژه‌ی خود را فراموش کرده‌اید؟ جدید دریافت کنید';
+$lang['profdeleted']           = 'حساب کاربری شما از این ویکی حذف گردیده است';
+$lang['profconfdelete']        = 'می‌خواهم حساب کاربری من از این ویکی حذف شود. <br/> این عمل قابل برگشت نیست.';
+$lang['profconfdeletemissing'] = 'جعبهٔ تأیید تیک نخورده است';
+$lang['proffail']              = 'بروزرسانی پروفایل کاربری انجام نشد.';
+$lang['pwdforget']             = 'گذرواژه‌ی خود را فراموش کرده‌اید؟ گذرواژه‌ی جدید دریافت کنید';
 $lang['resendna']              = 'این ویکی ارسال مجدد گذرواژه را پشتیبانی نمی‌کند';
 $lang['resendpwd']             = 'تعیین کلمه عبور جدید برای ';
-$lang['resendpwdmissing']      = 'متاسفم، شما باید تمام قسمت‌ها را پر کنید';
-$lang['resendpwdnouser']       = 'متاسفم، ما نتوانستیم این نام کاربری را در بانک خود پیدا کنیم';
+$lang['resendpwdmissing']      = 'متاسفم، شما باید تمام قسمت‌ها را پر کنید.';
+$lang['resendpwdnouser']       = 'متاسفم، ما نتوانستیم این نام کاربری را در پایگاه دادهٔ خود پیدا کنیم.';
 $lang['resendpwdbadauth']      = 'متاسفم، کد شناسایی معتبر نیست. از صحت لینک تاییدیه اطمینان حاصل کنید.';
-$lang['resendpwdconfirm']      = 'یک ایمیل تاییدیه‌ی آدرس به آدرس مورنظر ارسال شد. قبل از اینکه نامه‌ی دیگری قابل ارسال به این آدرس باشد، باید دستوراتی که در آن نامه آمده است را جهت تایید این مساله که این آدرس متعلق به شماست، اجرا کنید.';
-$lang['resendpwdsuccess']      = 'گذرواژه‌ی جدید شما توسط ایمیل ارسال شد';
+$lang['resendpwdconfirm']      = 'یک لینک تاییدیه آدرس از طریق ایمیل ارسال شد.';
+$lang['resendpwdsuccess']      = 'گذرواژه‌ی جدید شما توسط ایمیل ارسال شد.';
 $lang['license']               = 'به جز مواردی که ذکر می‌شود، مابقی محتویات ویکی تحت مجوز زیر می‌باشند:';
 $lang['licenseok']             = 'توجه: با ویرایش این صفحه، شما مجوز زیر را تایید می‌کنید:';
 $lang['searchmedia']           = 'نام فایل برای جستجو:';
 $lang['searchmedia_in']        = 'جستجو در %s';
-$lang['txt_upload']            = 'فایل را برای ارسال انتخاب کنید';
-$lang['txt_filename']          = 'ارسال به صورت (اختیاری)';
+$lang['txt_upload']            = 'فایل را برای آپلود انتخاب کنید:';
+$lang['txt_filename']          = 'ارسال به صورت (اختیاری):';
 $lang['txt_overwrt']           = 'بر روی فایل موجود بنویس';
 $lang['maxuploadsize']         = 'حداکثر %s برای هر فایل مجاز است.';
-$lang['lockedby']              = 'در حال حاضر قفل شده است';
-$lang['lockexpire']            = 'قفل منقضی شده است';
+$lang['lockedby']              = 'در حال حاضر قفل شده است:';
+$lang['lockexpire']            = 'قفل منقضی می‌شود در:';
 $lang['js']['willexpire']      = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
-$lang['js']['notsavedyet']     = 'تغییرات ذخیره شده از بین خواهد رفت.
- می‌خواهید ادامه دهید؟';
-$lang['js']['searchmedia']     = 'جستجو برای فایل';
-$lang['js']['keepopen']        = 'پنجره را ر زمان انتخاب باز نگه‌دار';
-$lang['js']['hidedetails']     = 'پتهان کردن جزییات';
+$lang['js']['notsavedyet']     = 'تغییرات ذخیره نشده از بین خواهد رفت.';
+$lang['js']['searchmedia']     = 'جستجو برای فایل‌ها';
+$lang['js']['keepopen']        = 'پنجره را در زمان انتخاب باز نگه‌دار';
+$lang['js']['hidedetails']     = 'پنهان کردن جزئیات';
 $lang['js']['mediatitle']      = 'تنظیمات پیوند';
 $lang['js']['mediadisplay']    = 'نوع پیوند';
 $lang['js']['mediaalign']      = 'هم‌ترازی';
@@ -117,13 +128,13 @@ $lang['js']['mediasize']       = 'اندازه تصویر';
 $lang['js']['mediatarget']     = 'هدف پیوند';
 $lang['js']['mediaclose']      = 'بستن';
 $lang['js']['mediainsert']     = 'درج کردن';
-$lang['js']['mediadisplayimg'] = 'نمایش تصویر';
+$lang['js']['mediadisplayimg'] = 'نمایش تصویر.';
 $lang['js']['mediadisplaylnk'] = 'فقط پیوند را نمایش بده.';
 $lang['js']['mediasmall']      = 'نگارش کوچک';
 $lang['js']['mediamedium']     = 'نگارش متوسط';
 $lang['js']['medialarge']      = 'نگارش بزرگ';
 $lang['js']['mediaoriginal']   = 'نگارش اصلی';
-$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزییات';
+$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزئیات';
 $lang['js']['mediadirect']     = 'پیوند مستقیم به اصلی';
 $lang['js']['medianolnk']      = 'بدون پیوند';
 $lang['js']['medianolink']     = 'تصویر را پیوند نکن';
@@ -135,45 +146,44 @@ $lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در ای
 شما می‌توانید پیوند‌ها رو کپی کنید.';
 $lang['js']['linkwiz']         = 'ویزارد پیوند';
 $lang['js']['linkto']          = 'پیوند به:';
-$lang['js']['del_confirm']     = 'واقعن تصمیم به حذف این موارد دارید؟';
-$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نسخه را بازیابی کنید؟';
-$lang['js']['media_diff']      = 'تفاوت ها را ببینید : ';
+$lang['js']['del_confirm']     = 'واقعا تصمیم به حذف این موارد دارید؟';
+$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نگارش را بازیابی کنید؟';
+$lang['js']['media_diff']      = 'تفاوت ها را ببینید: ';
 $lang['js']['media_diff_both'] = 'پهلو به پهلو';
 $lang['js']['media_diff_opacity'] = 'درخشش از';
 $lang['js']['media_diff_portions'] = 'کش رفتن';
-$lang['js']['media_select']    = 'انتخاب فایل -یا فایلها- ...';
+$lang['js']['media_select']    = 'انتخاب فایل‌ها...';
 $lang['js']['media_upload_btn'] = 'آپلود';
 $lang['js']['media_done_btn']  = 'انجام شد';
-$lang['js']['media_drop']      = 'فایل ها را در اینجا قرار دهید تا آپلود شود';
+$lang['js']['media_drop']      = 'فایل‌ها را در اینجا قرار دهید تا آپلود شود';
 $lang['js']['media_cancel']    = 'حذف';
-$lang['js']['media_overwrt']   = 'جاینوشت فایل های موجود';
-$lang['rssfailed']             = 'بروز خطا در هنگام واکشی';
-$lang['nothingfound']          = 'چیزی پیدا نشد';
+$lang['js']['media_overwrt']   = 'جاینوشت فایل‌های موجود';
+$lang['rssfailed']             = 'بروز خطا در هنگام واکشی این فید:';
+$lang['nothingfound']          = 'چیزی پیدا نشد.';
 $lang['mediaselect']           = 'فایل‌ها';
-$lang['fileupload']            = 'ارسال پرونده';
 $lang['uploadsucc']            = 'ارسال با موفقیت انجام شد';
-$lang['uploadfail']            = 'خطا در ارسال';
-$lang['uploadwrong']           = 'ارسال متوقف شد. این توسعه‌ی فایل ممنوع می‌باشد.';
-$lang['uploadexist']           = 'این فابل وجود دارد. عملی انجام نشد.';
-$lang['uploadbadcontent']      = 'محتوای فایل ارسال شده با توسعه‌ی %s متناقض است.';
+$lang['uploadfail']            = 'خطا در ارسال. شاید دسترسی‌ها نادرست است؟';
+$lang['uploadwrong']           = 'ارسال متوقف شد. این فرمت فایل ممنوع می‌باشد.';
+$lang['uploadexist']           = 'این فایل وجود دارد. عملی انجام نشد.';
+$lang['uploadbadcontent']      = 'محتوای فایل آپلود شده با فرمت %s یکسان نیست.';
 $lang['uploadspam']            = 'فایل ارسال شده توسط لیست سیاه اسپم‌ها مسدود شده است.';
 $lang['uploadxss']             = 'این صفحه حاوی اسکریپت یا کد اچ‌تی‌ام‌ال است که ممکن است به نادرست توسط مرورگر وب تفسیر شود.';
 $lang['uploadsize']            = 'فایل ارسال شده سنگین است. (بیشینه، %s)';
 $lang['deletesucc']            = 'فایل «%s» حذف شد.';
 $lang['deletefail']            = '«%s» حذف نمی‌شود، دسترسی‌ها را بررسی کنید.';
 $lang['mediainuse']            = 'فایل «%s» حذف نمی‌شود، چون هنوز در حال استفاده است.';
-$lang['namespaces']            = 'فضای‌نام';
+$lang['namespaces']            = 'فضای‌نام‌ها';
 $lang['mediafiles']            = 'فایل‌های موجود در';
-$lang['accessdenied']          = 'شما اجازه‌ی مشاهده‌ی این صفحه را ندارید.';
+$lang['accessdenied']          = 'شما اجازهٔ مشاهدهٔ این صفحه را ندارید.';
 $lang['mediausage']            = 'برای ارجاع دادن به فایل از نگارش زیر استفاده کنید.';
-$lang['mediaview']             = 'مشاهده‌ی فایل اصلی';
+$lang['mediaview']             = 'مشاهدهٔ فایل اصلی';
 $lang['mediaroot']             = 'ریشه';
-$lang['mediaupload']           = 'ارسال فایل به فضای‌نام کنونی. برای ایجاد زیرفضای‌نام‌ها، نام‌های آن‌ها را به عنوان پیشوندهایی که با دونقطه «:» جدا شده‌اند به نام فایل، در قسمت «ارسال به صورت» اضافه کنید.';
-$lang['mediaextchange']        = 'توسعه‌ی فایل از %s به %s تغییر داده شد.';
+$lang['mediaupload']           = 'ارسال فایل به فضای‌نام کنونی. برای ایجاد زیرفضای‌نام‌ها، پس از انتخاب فایل‌ها در قسمت «ارسال به صورت» به نام فایل نام‌های فضای‌نام‌ها را به عنوان پیشوندهایی که با دونقطه «:» جدا شده‌اند، اضافه کنید. همچنین فایل‌ها می‌توانند با کشیدن و ول کردن انتخاب شوند.';
+$lang['mediaextchange']        = 'فرمت فایل از %s به %s تغییر داده شد.';
 $lang['reference']             = 'ارجاع‌های';
 $lang['ref_inuse']             = 'این فایل نمی‌تواند حذف شود، زیرا هم‌چنان در این صفحه استفاده شده است:';
 $lang['ref_hidden']            = 'تعدادی مرجع در صفحاتی که شما دسترسی خواندن ندارید وجود دارد.';
-$lang['hits']                  = 'بازدید';
+$lang['hits']                  = 'بازدیدها';
 $lang['quickhits']             = 'جور کردن نام صفحات';
 $lang['toc']                   = 'فهرست مندرجات';
 $lang['current']               = 'فعلی';
@@ -184,10 +194,15 @@ $lang['difflink']              = 'پیوند به صفحه‌ی تفاوت‌ه
 $lang['diff_type']             = 'مشاهده تغییرات:';
 $lang['diff_inline']           = 'خطی';
 $lang['diff_side']             = 'کلی';
+$lang['diffprevrev']           = 'نگارش قبل';
+$lang['diffnextrev']           = 'نگارش بعد';
+$lang['difflastrev']           = 'آخرین نگارش';
+$lang['diffbothprevrev']       = 'نگارش قبل در دو طرف';
+$lang['diffbothnextrev']       = 'نگارش بعد در دو طرف';
 $lang['line']                  = 'خط';
-$lang['breadcrumb']            = 'ردپا';
-$lang['youarehere']            = 'محل شما';
-$lang['lastmod']               = 'آخرین ویرایش';
+$lang['breadcrumb']            = 'ردپا:';
+$lang['youarehere']            = 'محل شما:';
+$lang['lastmod']               = 'آخرین ویرایش:';
 $lang['by']                    = 'توسط';
 $lang['deleted']               = 'حذف شد';
 $lang['created']               = 'ایجاد شد';
@@ -236,24 +251,21 @@ $lang['qb_sig']                = 'افزودن امضا';
 $lang['qb_smileys']            = 'شکلک';
 $lang['qb_chars']              = 'حروف ویژه';
 $lang['upperns']               = 'پرش به فضای‌نام بالا';
-$lang['admin_register']        = 'یک حساب جدید بسازید';
 $lang['metaedit']              = 'ویرایش داده‌های متا';
 $lang['metasaveerr']           = 'نوشتن داده‌نما با مشکل مواجه شد';
 $lang['metasaveok']            = 'داده‌نما ذخیره شد';
-$lang['btn_img_backto']            = 'بازگشت به  %s';
-$lang['img_title']             = 'عنوان تصویر';
-$lang['img_caption']           = 'عنوان';
-$lang['img_date']              = 'تاریخ';
-$lang['img_fname']             = 'نام فایل';
-$lang['img_fsize']             = 'اندازه';
-$lang['img_artist']            = 'عکاس/هنرمند';
-$lang['img_copyr']             = 'دارنده‌ی حق تکثیر';
-$lang['img_format']            = 'فرمت';
-$lang['img_camera']            = 'دوربین';
-$lang['img_keywords']          = 'واژه‌های کلیدی';
-$lang['img_width']             = 'عرض';
-$lang['img_height']            = 'ارتفاع';
-$lang['btn_mediaManager']           = 'دیدن در مدیریت محتوای چند رسانه ای';
+$lang['img_title']             = 'عنوان تصویر:';
+$lang['img_caption']           = 'عنوان:';
+$lang['img_date']              = 'تاریخ:';
+$lang['img_fname']             = 'نام فایل:';
+$lang['img_fsize']             = 'اندازه:';
+$lang['img_artist']            = 'عکاس/هنرمند:';
+$lang['img_copyr']             = 'دارنده‌ی حق تکثیر:';
+$lang['img_format']            = 'فرمت:';
+$lang['img_camera']            = 'دوربین:';
+$lang['img_keywords']          = 'واژه‌های کلیدی:';
+$lang['img_width']             = 'عرض:';
+$lang['img_height']            = 'ارتفاع:';
 $lang['subscr_subscribe_success'] = '%s به لیست آبونه %s افزوده شد';
 $lang['subscr_subscribe_error'] = 'اشکال در افزودن %s به لیست آبونه %s';
 $lang['subscr_subscribe_noaddress'] = 'هیچ آدرسی برای این عضویت اضافه نشده است، شما نمی‌توانید به لیست آبونه اضافه شوید';
@@ -268,30 +280,36 @@ $lang['subscr_m_unsubscribe']  = 'لغو آبونه';
 $lang['subscr_m_subscribe']    = 'آبونه شدن';
 $lang['subscr_m_receive']      = 'دریافت کردن';
 $lang['subscr_style_every']    = 'ارسال رای‌نامه در تمامی تغییرات';
+$lang['subscr_style_digest']   = 'ایمیل خلاصه‌ی تغییرات هر روز (هر %.2f روز)';
+$lang['subscr_style_list']     = 'فهرست صفحات تغییریافته از آخرین ایمیل (هر %.2f روز)';
 $lang['authtempfail']          = 'معتبرسازی کابران موقتن مسدود می‌باشد. اگر این حالت پایدار بود، مدیر ویکی را باخبر سازید.';
-$lang['authpwdexpire']         = 'کلمه عبور شما در %d روز منقضی خواهد شد ، شما باید آن را زود تغییر دهید';
 $lang['i_chooselang']          = 'انتخاب زبان';
-$lang['i_installer']           = 'نصب کننده‌ی Dokuwiki';
+$lang['i_installer']           = 'نصب کننده‌ی دوکوویکی';
 $lang['i_wikiname']            = 'نام ویکی';
 $lang['i_enableacl']           = 'فعال بودن کنترل دسترسی‌ها (توصیه شده)';
 $lang['i_superuser']           = 'کاربر اصلی';
 $lang['i_problems']            = 'نصب کننده با مشکلات زیر مواجه شد. در صورت رفع این مشکلات، امکان ادامه نصب خواهد بود.';
-$lang['i_modified']            = 'به دلایل امنیتی، این اسکریپت فقط با نصب تازه و بدون تغییر DokuWiki کار خواهد کرد.شما باید دوباره فایل فشرده را باز کنید <a href="http://dokuwiki.org/install">راهنمای نصب DokuWiki</a> را بررسی کنید.';
-$lang['i_funcna']              = 'تابع <code>%s</code> در PHP موجود نیست. ممکن است شرکت خدمات وب شما آن را مسدود کرده باشد.';
-$lang['i_phpver']              = 'نگارش پی‌اچ‌پی <code>%s</code> پایین‌تر از نگارش مورد نیاز، یعنی <code>%s</code> می‌باشد. خواهشمندیم به روز رسانی کنید.';
+$lang['i_modified']            = 'به دلایل امنیتی، این اسکریپت فقط با نصب تازه و بدون تغییر دوکوویکی کار خواهد کرد. شما باید دوباره فایل فشرده را باز کنید <a href="http://dokuwiki.org/install">راهنمای نصب DokuWiki</a> را بررسی کنید.';
+$lang['i_funcna']              = 'تابع <code>%s</code> در پی‌اچ‌پی موجود نیست. ممکن است شرکت خدمات وب شما آن را مسدود کرده باشد.';
+$lang['i_phpver']              = 'نگارش پی‌اچ‌پی <code>%s</code> پایین‌تر از نگارش مورد نیاز، یعنی <code>%s</code> است. خواهشمندیم به روز رسانی کنید.';
+$lang['i_mbfuncoverload']      = 'برای اجرای دوکوویکی باید mbstring.func_overload را در php.ini غیرفعال کنید.';
 $lang['i_permfail']            = 'شاخه‌ی <code>%s</code> قابلیت نوشتن ندارد. شما باید دسترسی‌های این شاخه را تنظیم کنید!';
 $lang['i_confexists']          = '<code>%s</code> پیش‌تر موجود است';
 $lang['i_writeerr']            = 'توانایی ایجاد <code>%s</code> نیست. شما باید دسترسی‌های شاخه یا فایل را بررسی کنید و فایل را به طور دستی ایجاد کنید.';
 $lang['i_badhash']             = 'فایل dokuwiki.php غیرقابل تشخیص بوده یا تغییر کرده است (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - غیرقانونی و یا مقادیر تهی';
-$lang['i_success']             = 'تنظیمات با موفقیت به پایان رسید. بهتر است فایل install.php رو حذف کنید. برای ادامه <a href="doku.php?id=wiki:welcome">این‌جا</a> کلیک کنید.';
+$lang['i_success']             = 'تنظیمات با موفقیت به پایان رسید. بهتر است فایل install.php را حذف کنید. برای ادامه <a href="doku.php?id=wiki:welcome">این‌جا</a> کلیک کنید.';
 $lang['i_failure']             = 'مشکلاتی در زمان نوشتن فایل تنظیمات پیش آمده است. شما باید این مشکلات را پیش از استفاده از <a href="doku.php?id=wiki:welcome">DokuWiki</a> برطرف کنید.';
 $lang['i_policy']              = 'کنترل دسترسی‌های اولیه';
 $lang['i_pol0']                = 'ویکی باز (همه می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
 $lang['i_pol1']                = 'ویکی عمومی (همه می‌توانند بخوانند، کاربران ثبت شده می‌توانند بنویسند و فایل ارسال کنند)';
 $lang['i_pol2']                = 'ویکی بسته (فقط کاربران ثبت شده می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
+$lang['i_allowreg']            = 'اجازه دهید که کاربران خود را ثبت نام کنند';
 $lang['i_retry']               = 'تلاش مجدد';
-$lang['i_license']             = 'لطفن مجوز این محتوا را وارد کنید:';
+$lang['i_license']             = 'لطفاً مجوزی که می‌خواهید برای محتوایتان استفاده کنید را وارد کنید:';
+$lang['i_license_none']        = 'هیچ اطلاعات مجوزی را نشان نده';
+$lang['i_pop_field']           = 'لطفاً به ما کمک کنید تا تجربهٔ دوکوویکی را بهبود دهیم.';
+$lang['i_pop_label']           = 'ماهی یک بار، اطلاعات ناشناس دربارهٔ نحوهٔ استفاده به توسعه‌دهندگان دوکوویکی ارسال کن';
 $lang['recent_global']         = 'شما هم‌اکنون تغییرات فضای‌نام <b>%s</b> را مشاهده می‌کنید. شما هم‌چنین می‌توانید <a href="%s">تغییرات اخیر در کل ویکی را مشاهده نمایید</a>.';
 $lang['years']                 = '%d سال پیش';
 $lang['months']                = '%d ماه پیش';
@@ -309,7 +327,7 @@ $lang['media_edittab']         = 'ویرایش';
 $lang['media_historytab']      = 'تاریخچه';
 $lang['media_list_thumbs']     = 'ریز عکسها';
 $lang['media_list_rows']       = 'سطرها';
-$lang['media_sort_name']       = 'ستون ها';
+$lang['media_sort_name']       = 'نام';
 $lang['media_sort_date']       = 'تاریخ';
 $lang['media_namespaces']      = 'انتخاب فضای نام';
 $lang['media_files']           = 'فایل در %s';
@@ -317,10 +335,19 @@ $lang['media_upload']          = 'آپلود به %s';
 $lang['media_search']          = 'جستجو در %s';
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s در %s';
-$lang['media_edit']            = '%s ویرایش';
-$lang['media_history']         = 'تاریخچه %s';
-$lang['media_meta_edited']     = 'فرا داده ها ویرایش شدند.';
-$lang['media_perm_read']       = 'متاسفانه ، شما حق خواندن این فایل ها را ندارید.';
-$lang['media_perm_upload']     = 'متاسفانه ، شما حق آپلود این فایل ها را ندارید.';
-$lang['media_update']          = 'آپلود نسخه جدید';
+$lang['media_edit']            = 'ویرایش %s';
+$lang['media_history']         = 'تاریخچهٔ %s';
+$lang['media_meta_edited']     = 'فراداده‌ها ویرایش شدند.';
+$lang['media_perm_read']       = 'متاسفانه شما دسترسی‌های لازم برای خواندن این فایل‌ها را ندارید.';
+$lang['media_perm_upload']     = 'متاسفانه شما دسترسی‌های لازم برای آپلود این فایل‌ها را ندارید.';
+$lang['media_update']          = 'آپلود نسخه‌ی جدید';
 $lang['media_restore']         = 'بازیابی این نسخه';
+$lang['media_acl_warning']     = 'این لیست ممکن است به خاطر محدودیتهای دسترسیهای ACL و صفحات پنهان کامل نباشد.';
+$lang['currentns']             = 'فضای نام جاری';
+$lang['searchresult']          = 'نتیجه‌ی جستجو';
+$lang['plainhtml']             = 'HTML ساده';
+$lang['wikimarkup']            = 'نشانه‌گذاری ویکی';
+$lang['page_nonexist_rev']     = 'صفحه %s وجود نداشت. این صفحه معاقباً در<a href="%s">%s</a> ایجاد شد.';
+$lang['unable_to_parse_date']  = 'امکان تجزیه و تحلیل پارامتر «%s» وجود ندارد.';
+$lang['email_signature_text']  = 'این ایمیل توسط دوکوویکی تولید شده است
+@DOKUWIKIURL@';
