@@ -2,16 +2,20 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Seungheon Song <esketch@gmail.com>
  * @author Hyun Kim <lawfully@gmail.com>
  * @author jk Lee
- * @author dongnak@gmail.com
+ * @author dongnak <dongnak@gmail.com>
  * @author Song Younghwan <purluno@gmail.com>
  * @author Seung-Chul Yoo <dryoo@live.com>
- * @author erial2@gmail.com
+ * @author erial2 <erial2@gmail.com>
  * @author Myeongjin <aranet100@gmail.com>
  * @author Gerrit Uitslag <klapinklapin@gmail.com>
  * @author Garam <rowain8@gmail.com>
+ * @author Young gon Cha <garmede@gmail.com>
+ * @author hyeonsoft <hyeonsoft@live.co.kr>
+ * @author S.H. Lee <tuders@naver.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -28,8 +32,8 @@ $lang['btn_search']            = '검색';
 $lang['btn_save']              = '저장';
 $lang['btn_preview']           = '미리 보기';
 $lang['btn_top']               = '맨 위로';
-$lang['btn_newer']             = '<< 최근';
-$lang['btn_older']             = '이전 >>';
+$lang['btn_newer']             = '<< 더 최근';
+$lang['btn_older']             = '덜 최근 >>';
 $lang['btn_revs']              = '이전 판';
 $lang['btn_recent']            = '최근 바뀜';
 $lang['btn_upload']            = '올리기';
@@ -39,33 +43,34 @@ $lang['btn_secedit']           = '편집';
 $lang['btn_login']             = '로그인';
 $lang['btn_logout']            = '로그아웃';
 $lang['btn_admin']             = '관리';
-$lang['btn_update']            = '바꾸기';
+$lang['btn_update']            = '업데이트';
 $lang['btn_delete']            = '삭제';
 $lang['btn_back']              = '뒤로';
-$lang['btn_backlink']          = '백링크';
-$lang['btn_backtomedia']       = '미디어 파일 선택으로 돌아가기';
+$lang['btn_backlink']          = '역링크';
 $lang['btn_subscribe']         = '구독 관리';
-$lang['btn_profile']           = '개인 정보 바꾸기';
+$lang['btn_profile']           = '프로필 업데이트';
 $lang['btn_reset']             = '재설정';
 $lang['btn_resendpwd']         = '새 비밀번호 설정';
 $lang['btn_draft']             = '초안 편집';
-$lang['btn_recover']           = '초안 되돌리기';
+$lang['btn_recover']           = '초안 복구';
 $lang['btn_draftdel']          = '초안 삭제';
 $lang['btn_revert']            = '되돌리기';
 $lang['btn_register']          = '등록';
 $lang['btn_apply']             = '적용';
-$lang['btn_media']             = '미디어 관리';
+$lang['btn_media']             = '미디어 관리자';
 $lang['btn_deleteuser']        = '내 계정 제거';
-$lang['loggedinas']            = '로그인한 사용자';
+$lang['btn_img_backto']        = '%s(으)로 돌아가기';
+$lang['btn_mediaManager']      = '미디어 관리자에서 보기';
+$lang['loggedinas']            = '로그인한 사용자:';
 $lang['user']                  = '사용자 이름';
 $lang['pass']                  = '비밀번호';
 $lang['newpass']               = '새 비밀번호';
 $lang['oldpass']               = '현재 비밀번호 확인';
-$lang['passchk']               = '비밀번호 다시 확인';
+$lang['passchk']               = '다시 확인';
 $lang['remember']              = '기억하기';
 $lang['fullname']              = '실명';
 $lang['email']                 = '이메일';
-$lang['profile']               = '개인 정보';
+$lang['profile']               = '사용자 프로필';
 $lang['badlogin']              = '죄송하지만 사용자 이름이나 비밀번호가 잘못되었습니다.';
 $lang['badpassconfirm']        = '죄송하지만 비밀번호가 잘못되었습니다';
 $lang['minoredit']             = '사소한 바뀜';
@@ -73,23 +78,25 @@ $lang['draftdate']             = '초안 자동 저장 시간';
 $lang['nosecedit']             = '한 동안 문서가 바뀌었으며, 문단 정보가 오래되어 문서 전체를 대신 열었습니다.';
 $lang['regmissing']            = '죄송하지만 모든 필드를 채워야 합니다.';
 $lang['reguexists']            = '죄송하지만 같은 이름을 사용하는 사용자가 있습니다.';
-$lang['regsuccess']            = '사용자를 만들었으며 비밀번호는 이메일로 보냈습니다.';
-$lang['regsuccess2']           = '사용자를 만들었습니다.';
-$lang['regmailfail']           = '비밀번호를 이메일로 보내는 동안 오류가 발생했습니다. 관리자에게 문의하세요!';
-$lang['regbadmail']            = '주어진 이메일 주소가 잘못되었습니다 - 오류라고 생각하면 관리자에게 문의하세요';
-$lang['regbadpass']            = '새 비밀번호가 같지 않습니다. 다시 입력하세요.';
+$lang['regsuccess']            = '사용자 계정을 만들었으며 비밀번호는 이메일로 보냈습니다.';
+$lang['regsuccess2']           = '사용자 계정을 만들었습니다.';
+$lang['regfail']               = '사용자 계정을 만들 수 없었습니다.';
+$lang['regmailfail']           = '비밀번호를 이메일로 보내는 동안 오류가 발생했습니다. 관리자에게 문의해주세요!';
+$lang['regbadmail']            = '주어진 이메일 주소가 잘못되었습니다 - 오류라고 생각하면 관리자에게 문의해주세요';
+$lang['regbadpass']            = '두 주어진 비밀번호가 일치하지 않습니다, 다시 입력하세요.';
 $lang['regpwmail']             = '도쿠위키 비밀번호';
-$lang['reghere']               = '계정이 없나요? 계정을 등록할 수 있습니다';
-$lang['profna']                = '이 위키는 개인 정보 수정을 할 수 없습니다';
+$lang['reghere']               = '계정이 없나요? 계정을 등록하세요';
+$lang['profna']                = '이 위키는 프로필 수정을 할 수 없습니다';
 $lang['profnochange']          = '바뀐 내용이 없습니다.';
-$lang['profnoempty']           = '이름이나 이메일 주소가 비었습니다.';
-$lang['profchanged']           = '개인 정보가 성공적으로 바뀌었습니다.';
-$lang['profnodelete']          = '이 위키는 사용자 삭제를 지원하지 않습니다';
+$lang['profnoempty']           = '빈 이름이나 이메일 주소는 허용하지 않습니다.';
+$lang['profchanged']           = '프로필이 성공적으로 바뀌었습니다.';
+$lang['profnodelete']          = '이 위키는 사용자 계정 삭제를 지원하지 않습니다';
 $lang['profdeleteuser']        = '계정 삭제';
 $lang['profdeleted']           = '당신의 사용자 계정이 이 위키에서 삭제되었습니다';
 $lang['profconfdelete']        = '이 위키에서 내 계정을 제거하고 싶습니다. <br/> 이 행동은 되돌릴 수 없습니다.';
 $lang['profconfdeletemissing'] = '선택하지 않은 확인 상자를 확인';
-$lang['pwdforget']             = '비밀번호를 잊으셨나요? 비밀번호를 재설정할 수 있습니다';
+$lang['proffail']              = '사용자 프로필이 업데이트되지 않았습니다.';
+$lang['pwdforget']             = '비밀번호를 잊으셨나요? 비밀번호를 재설정하세요';
 $lang['resendna']              = '이 위키는 비밀번호 재설정을 지원하지 않습니다.';
 $lang['resendpwd']             = '다음으로 새 비밀번호 보내기';
 $lang['resendpwdmissing']      = '죄송하지만 모든 필드를 채워야 합니다.';
@@ -101,22 +108,22 @@ $lang['license']               = '별도로 명시하지 않을 경우, 이 위
 $lang['licenseok']             = '참고: 이 문서를 편집하면 내용은 다음 라이선스에 따라 배포하는 데 동의합니다:';
 $lang['searchmedia']           = '파일 이름 검색:';
 $lang['searchmedia_in']        = '%s에서 검색';
-$lang['txt_upload']            = '올릴 파일 선택';
-$lang['txt_filename']          = '올릴 파일 이름 (선택 사항)';
+$lang['txt_upload']            = '올릴 파일 선택:';
+$lang['txt_filename']          = '올릴 파일 이름 (선택 사항):';
 $lang['txt_overwrt']           = '기존 파일에 덮어쓰기';
-$lang['maxuploadsize']         = '최대 올리기 용량. 파일당 %s입니다.';
-$lang['lockedby']              = '현재 잠겨진 사용자';
-$lang['lockexpire']            = '잠금 해제 시간';
+$lang['maxuploadsize']         = '최대 올리기 용량. 파일당 %s.';
+$lang['lockedby']              = '현재 잠근 사용자:';
+$lang['lockexpire']            = '잠금 해제 시간:';
 $lang['js']['willexpire']      = '잠시 후 편집 잠금이 해제됩니다.\n편집 충돌을 피하려면 미리 보기를 눌러 잠금 시간을 다시 설정하세요.';
 $lang['js']['notsavedyet']     = '저장하지 않은 바뀜이 사라집니다.';
 $lang['js']['searchmedia']     = '파일 검색';
-$lang['js']['keepopen']        = '선택할 때 창을 열어 놓기';
+$lang['js']['keepopen']        = '선택할 때 열어 놓은 창을 유지하기';
 $lang['js']['hidedetails']     = '자세한 정보 숨기기';
 $lang['js']['mediatitle']      = '링크 설정';
-$lang['js']['mediadisplay']    = '링크 형태';
+$lang['js']['mediadisplay']    = '링크 유형';
 $lang['js']['mediaalign']      = '배치';
 $lang['js']['mediasize']       = '그림 크기';
-$lang['js']['mediatarget']     = '링크 목표';
+$lang['js']['mediatarget']     = '링크 타겟';
 $lang['js']['mediaclose']      = '닫기';
 $lang['js']['mediainsert']     = '넣기';
 $lang['js']['mediadisplayimg'] = '그림을 보여줍니다.';
@@ -133,7 +140,7 @@ $lang['js']['medialeft']       = '왼쪽으로 그림 배치';
 $lang['js']['mediaright']      = '오른쪽으로 그림 배치';
 $lang['js']['mediacenter']     = '가운데으로 그림 배치';
 $lang['js']['medianoalign']    = '배치하지 않음';
-$lang['js']['nosmblinks']      = '윈도우 공유 파일과의 연결은 마이크로소프트 인터넷 익스플로러에서만 동작합니다.\n그러나 링크를 복사하거나 붙여넣기를 할 수 있습니다.';
+$lang['js']['nosmblinks']      = 'Windows 공유 파일과의 연결은 Microsoft Internet Explorer에서만 동작합니다.\n그러나 링크를 복사하거나 붙여넣기를 할 수 있습니다.';
 $lang['js']['linkwiz']         = '링크 마법사';
 $lang['js']['linkto']          = '다음으로 연결:';
 $lang['js']['del_confirm']     = '정말 선택된 항목을 삭제하겠습니까?';
@@ -151,7 +158,6 @@ $lang['js']['media_overwrt']   = '기존 파일에 덮어쓰기';
 $lang['rssfailed']             = '이 피드를 가져오는 동안 오류가 발생했습니다:';
 $lang['nothingfound']          = '아무 것도 없습니다.';
 $lang['mediaselect']           = '미디어 파일';
-$lang['fileupload']            = '미디어 파일 올리기';
 $lang['uploadsucc']            = '올리기 성공';
 $lang['uploadfail']            = '올리기가 실패되었습니다. 잘못된 권한 때문일지도 모릅니다.';
 $lang['uploadwrong']           = '올리기가 거부되었습니다. 금지된 파일 확장자입니다!';
@@ -166,14 +172,14 @@ $lang['mediainuse']            = '"%s" 파일을 삭제할 수 없습니다 - 
 $lang['namespaces']            = '이름공간';
 $lang['mediafiles']            = '사용할 수 있는 파일 목록';
 $lang['accessdenied']          = '이 문서를 볼 권한이 없습니다.';
-$lang['mediausage']            = '이 파일을 참고하려면 다음 문법을 사용하세요:';
+$lang['mediausage']            = '이 파일을 참조하려면 다음 문법을 사용하세요:';
 $lang['mediaview']             = '원본 파일 보기';
 $lang['mediaroot']             = '루트';
 $lang['mediaupload']           = '파일을 현재 이름공간으로 올립니다. 하위 이름공간으로 만들려면 선택한 파일 이름 앞에 쌍점(:)으로 구분되는 이름을 붙이면 됩니다. 파일을 드래그 앤 드롭해 선택할 수 있습니다.';
 $lang['mediaextchange']        = '파일 확장자가 .%s에서 .%s(으)로 바뀌었습니다!';
-$lang['reference']             = '참고';
+$lang['reference']             = '다음을 참조';
 $lang['ref_inuse']             = '다음 문서에서 아직 사용 중이므로 파일을 삭제할 수 없습니다:';
-$lang['ref_hidden']            = '문서의 일부 참고는 읽을 수 있는 권한이 없습니다';
+$lang['ref_hidden']            = '문서의 일부 참조는 읽을 수 있는 권한이 없습니다';
 $lang['hits']                  = '조회 수';
 $lang['quickhits']             = '일치하는 문서 이름';
 $lang['toc']                   = '목차';
@@ -185,17 +191,22 @@ $lang['difflink']              = '차이 보기로 링크';
 $lang['diff_type']             = '차이 보기:';
 $lang['diff_inline']           = '직렬 방식';
 $lang['diff_side']             = '다중 창 방식';
+$lang['diffprevrev']           = '이전 판';
+$lang['diffnextrev']           = '다음 판';
+$lang['difflastrev']           = '마지막 판';
+$lang['diffbothprevrev']       = '양쪽 이전 판';
+$lang['diffbothnextrev']       = '양쪽 다음 판';
 $lang['line']                  = '줄';
-$lang['breadcrumb']            = '추적';
-$lang['youarehere']            = '현재 위치';
-$lang['lastmod']               = '마지막으로 수정됨';
+$lang['breadcrumb']            = '추적:';
+$lang['youarehere']            = '현재 위치:';
+$lang['lastmod']               = '마지막으로 수정됨:';
 $lang['by']                    = '저자';
 $lang['deleted']               = '제거됨';
-$lang['created']               = '새로 만듦';
+$lang['created']               = '만듦';
 $lang['restored']              = '이전 판으로 되돌림 (%s)';
 $lang['external_edit']         = '바깥 편집';
 $lang['summary']               = '편집 요약';
-$lang['noflash']               = '이 내용을 표시하기 위해서 <a href="http://www.adobe.com/products/flashplayer/">Adobe 플래시 플러그인</a>이 필요합니다.';
+$lang['noflash']               = '이 내용을 표시하기 위해서 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 플러그인</a>이 필요합니다.';
 $lang['download']              = '조각 다운로드';
 $lang['tools']                 = '도구';
 $lang['user_tools']            = '사용자 도구';
@@ -232,29 +243,26 @@ $lang['qb_extlink']            = '바깥 링크';
 $lang['qb_hr']                 = '가로줄';
 $lang['qb_ol']                 = '순서 있는 목록';
 $lang['qb_ul']                 = '순서 없는 목록';
-$lang['qb_media']              = '그림과 기타 파일 추가 (새 창에서 열림)';
+$lang['qb_media']              = '그림과 다른 파일 추가 (새 창에서 열림)';
 $lang['qb_sig']                = '서명 넣기';
 $lang['qb_smileys']            = '이모티콘';
 $lang['qb_chars']              = '특수 문자';
 $lang['upperns']               = '상위 이름공간으로 이동';
-$lang['admin_register']        = '새 사용자 추가';
 $lang['metaedit']              = '메타데이터 편집';
 $lang['metasaveerr']           = '메타데이터 쓰기 실패';
 $lang['metasaveok']            = '메타데이터 저장됨';
-$lang['img_backto']            = '뒤로';
-$lang['img_title']             = '제목';
-$lang['img_caption']           = '설명';
-$lang['img_date']              = '날짜';
-$lang['img_fname']             = '파일 이름';
-$lang['img_fsize']             = '크기';
-$lang['img_artist']            = '촬영자';
-$lang['img_copyr']             = '저작권';
-$lang['img_format']            = '포맷';
-$lang['img_camera']            = '카메라';
-$lang['img_keywords']          = '키워드';
-$lang['img_width']             = '너비';
-$lang['img_height']            = '높이';
-$lang['img_manager']           = '미디어 관리자에서 보기';
+$lang['img_title']             = '제목:';
+$lang['img_caption']           = '설명:';
+$lang['img_date']              = '날짜:';
+$lang['img_fname']             = '파일 이름:';
+$lang['img_fsize']             = '크기:';
+$lang['img_artist']            = '촬영자:';
+$lang['img_copyr']             = '저작권:';
+$lang['img_format']            = '포맷:';
+$lang['img_camera']            = '카메라:';
+$lang['img_keywords']          = '키워드:';
+$lang['img_width']             = '너비:';
+$lang['img_height']            = '높이:';
 $lang['subscr_subscribe_success'] = '%s 사용자가 %s 구독 목록에 추가했습니다';
 $lang['subscr_subscribe_error'] = '%s 사용자가 %s 구독 목록에 추가하는데 실패했습니다';
 $lang['subscr_subscribe_noaddress'] = '로그인으로 연결된 주소가 없기 때문에 구독 목록에 추가할 수 없습니다';
@@ -272,29 +280,31 @@ $lang['subscr_style_every']    = '모든 바뀜을 이메일로 받기';
 $lang['subscr_style_digest']   = '각 문서의 바뀜을 요약 (매 %.2f일 마다)';
 $lang['subscr_style_list']     = '마지막 이메일 이후 바뀐 문서의 목록 (매 %.2f일 마다)';
 $lang['authtempfail']          = '사용자 인증을 일시적으로 사용할 수 없습니다. 만약 계속해서 문제가 발생한다면 위키 관리자에게 문의하시기 바랍니다.';
-$lang['authpwdexpire']         = '비밀번호를 바꾼지 %d일이 지났으며, 비밀번호를 곧 바꿔야 합니다.';
 $lang['i_chooselang']          = '사용할 언어를 선택하세요';
-$lang['i_installer']           = '도쿠위키 설치';
+$lang['i_installer']           = '도쿠위키 설치 관리자';
 $lang['i_wikiname']            = '위키 이름';
 $lang['i_enableacl']           = 'ACL 활성화 (권장)';
 $lang['i_superuser']           = '슈퍼 사용자';
-$lang['i_problems']            = '설치하는 동안 아래와 같은 문제가 발생했습니다. 문제를 해결한 후 설치를 계속할 수 있습니다.';
+$lang['i_problems']            = '설치 관리자가 아래에 나와 있는 몇 가지 문제를 찾았습니다. 문제를 해결하지 전까지 설치를 계속할 수 없습니다.';
 $lang['i_modified']            = '보안 상의 이유로 이 스크립트는 수정되지 않은 새 도쿠위키 설치에서만 동작됩니다.
-다운로드한 압축 패키지를 다시 설치하거나 <a href="http://dokuwiki.org/ko:install">도쿠위키 설치 과정</a>을 참고해서 설치하세요.';
+                                  다운로드한 압축 패키지를 다시 설치하거나 <a href="http://dokuwiki.org/ko:install">도쿠위키 설치 과정</a>을 참조해서 설치하세요.';
 $lang['i_funcna']              = '<code>%s</code> PHP 함수를 사용할 수 없습니다. 호스트 제공자가 어떤 이유에서인지 막아 놓았을지 모릅니다.';
 $lang['i_phpver']              = 'PHP <code>%s</code> 버전은 필요한 <code>%s</code> 버전보다 오래되었습니다. PHP를 업그레이드할 필요가 있습니다.';
+$lang['i_mbfuncoverload']      = '도쿠위키를 실행하려면 mbstring.func_overload를 php.ini에서 비활성화해야 합니다.';
 $lang['i_permfail']            = '<code>%s</code>는 도쿠위키가 쓰기 가능 권한이 없습니다. 먼저 이 디렉터리에 쓰기 권한이 설정되어야 합니다!';
 $lang['i_confexists']          = '<code>%s</code>(은)는 이미 존재합니다';
 $lang['i_writeerr']            = '<code>%s</code>(을)를 만들 수 없습니다. 먼저 디렉터리/파일 권한을 확인하고 파일을 수동으로 만드세요.';
 $lang['i_badhash']             = 'dokuwiki.php를 인식할 수 없거나 원본 파일이 아닙니다 (해시=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - 잘못되었거나 빈 값입니다';
-$lang['i_success']             = '환경 설정이 성공적으로 끝났습니다. 지금 install.php를 지워도 상관없습니다. <a href="doku.php?id=wiki:welcome">새 도쿠위키</a>로 들어가세요.';
-$lang['i_failure']             = '환경 설정 파일에 쓰는 도중에 오류가 발생했습니다. <a href="doku.php?id=wiki:welcome">새 도쿠위키</a>를 사용하기 전에 수동으로 문제를 해결해야 합니다.';
+$lang['i_success']             = '환경 설정이 성공적으로 끝났습니다. 지금 install.php를 지워도 상관없습니다.
+                                 <a href="doku.php?id=wiki:welcome">새 도쿠위키</a>로 들어가세요.';
+$lang['i_failure']             = '환경 설정 파일에 쓰는 도중에 오류가 발생했습니다.
+                                  <a href="doku.php?id=wiki:welcome">새 도쿠위키</a>를 사용하기 전에 수동으로 문제를 해결해야 합니다.';
 $lang['i_policy']              = '초기 ACL 정책';
 $lang['i_pol0']                = '열린 위키 (누구나 읽기, 쓰기, 올리기가 가능합니다)';
 $lang['i_pol1']                = '공개 위키 (누구나 읽을 수 있지만, 등록된 사용자만 쓰기와 올리기가 가능합니다)';
 $lang['i_pol2']                = '닫힌 위키 (등록된 사용자만 읽기, 쓰기, 올리기가 가능합니다)';
-$lang['i_allowreg']            = '사용자 자신이 등록할 수 있음';
+$lang['i_allowreg']            = '사용자 자신이 등록할 수 있도록 하기';
 $lang['i_retry']               = '다시 시도';
 $lang['i_license']             = '내용을 배포하기 위한 라이선스를 선택하세요:';
 $lang['i_license_none']        = '라이선스 정보를 보여주지 않습니다';
@@ -302,7 +312,7 @@ $lang['i_pop_field']           = '도쿠위키 경험을 개선하는 데 도움
 $lang['i_pop_label']           = '한 달에 한 번씩, 도쿠위키 개발자에게 익명의 사용 데이터를 보냅니다';
 $lang['recent_global']         = '현재 <b>%s</b> 이름공간을 구독 중입니다. <a href="%s">전체 위키의 최근 바뀜도 볼 수</a> 있습니다.';
 $lang['years']                 = '%d년 전';
-$lang['months']                = '%d달 전';
+$lang['months']                = '%d개월 전';
 $lang['weeks']                 = '%d주 전';
 $lang['days']                  = '%d일 전';
 $lang['hours']                 = '%d시간 전';
@@ -324,7 +334,7 @@ $lang['media_files']           = '%s에 있는 파일';
 $lang['media_upload']          = '%s에 올리기';
 $lang['media_search']          = '%s에서 검색';
 $lang['media_view']            = '%s';
-$lang['media_viewold']         = '%s (%s에 있음)';
+$lang['media_viewold']         = '%2$s에 있는 %1$s';
 $lang['media_edit']            = '%s 편집';
 $lang['media_history']         = '%s의 역사';
 $lang['media_meta_edited']     = '메타데이터 편집됨';
@@ -332,7 +342,11 @@ $lang['media_perm_read']       = '죄송하지만 파일을 읽을 권한이 없
 $lang['media_perm_upload']     = '죄송하지만 파일을 올릴 권한이 없습니다.';
 $lang['media_update']          = '새 판 올리기';
 $lang['media_restore']         = '이 판으로 되돌리기';
+$lang['media_acl_warning']     = '이 목록은 ACL로 제한되어 있고 숨겨진 문서이기 때문에 완전하지 않을 수 있습니다.';
 $lang['currentns']             = '현재 이름공간';
 $lang['searchresult']          = '검색 결과';
 $lang['plainhtml']             = '일반 HTML';
 $lang['wikimarkup']            = '위키 문법';
+$lang['page_nonexist_rev']     = '문서가 %s에 존재하지 않았습니다. 그 뒤로 <a href="%s">%s</a>에 만들어졌습니다.';
+$lang['unable_to_parse_date']  = '"%s" 변수에서 구문 분석할 수 없습니다.';
+$lang['email_signature_text']  = '이 메일은 @DOKUWIKIURL@에서 도쿠위키가 생성했습니다';
