@@ -5,6 +5,7 @@
  *
  * @author Saroj Kumar Dhakal <lotusnagarkot@gmail.com>
  * @author Saroj Kumar Dhakal <lotusnagarkot@yahoo.com>
+ * @author सरोज ढकाल <lotusnagarkot@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -36,15 +37,21 @@ $lang['btn_update']            = 'अध्यावधिक गर्नुह
 $lang['btn_delete']            = 'मेटाउनुहोस् ';
 $lang['btn_back']              = 'पछाडि';
 $lang['btn_backlink']          = 'पछाडिका लिङ्कहरु ';
-$lang['btn_backtomedia']       = 'मिडिया छनौटमा फर्कनुहोस्';
 $lang['btn_subscribe']         = 'पृष्ठ परिवर्तन ग्राह्य गर्नुहोस्';
 $lang['btn_profile']           = 'प्रोफाइल अध्यावधिक गर्नुहोस् ';
 $lang['btn_reset']             = 'पूर्वरुपमा फर्काउनुहोस';
+$lang['btn_resendpwd']         = 'नयाँ पासवर्ड राख्नुहोस';
 $lang['btn_draft']             = ' ड्राफ्ट सम्पादन गर्नुहोस् ';
 $lang['btn_recover']           = 'पहिलेको ड्राफ्ट हासिल गर्नुहोस ';
 $lang['btn_draftdel']          = ' ड्राफ्ट मेटाउनुहोस् ';
+$lang['btn_revert']            = 'पूर्वरूपमा फर्काउने';
 $lang['btn_register']          = 'दर्ता  गर्नुहोस्';
-$lang['loggedinas']            = 'प्रवेश गर्नुहोस् ';
+$lang['btn_apply']             = 'लागु गर्ने';
+$lang['btn_media']             = 'मेडिया व्यवस्थापक';
+$lang['btn_deleteuser']        = 'खाता हटाउने';
+$lang['btn_img_backto']        = 'फिर्ता%s';
+$lang['btn_mediaManager']      = 'मेडिया व्यवस्थापकमा हेर्ने';
+$lang['loggedinas']            = 'प्रवेश गर्नुहोस् :';
 $lang['user']                  = 'प्रयोगकर्ता ';
 $lang['pass']                  = 'प्रवेशशव्द';
 $lang['newpass']               = 'नयाँ प्रवेशशव्द';
@@ -55,6 +62,7 @@ $lang['fullname']              = 'पूरा नाम';
 $lang['email']                 = 'इमेल';
 $lang['profile']               = 'प्रयोगकर्ताको प्रोफाइल';
 $lang['badlogin']              = 'माफ गर्नुहोस् , प्रयोगकर्तानाम वा प्रवेशशव्द गलत भयो  ';
+$lang['badpassconfirm']        = 'माफ गर्नुहोस् , पासवर्ड गलत छ ';
 $lang['minoredit']             = 'सामान्य परिवर्तन';
 $lang['draftdate']             = 'ड्राफ्ट स्वचालित रुपमा वचत भएको';
 $lang['nosecedit']             = 'यो पृष्ठ यसै बखतमा परिवर्तन भयो, खण्ड जानकारी अध्यावधिक हुन सकेन र पूरै पृष्ठ लोड भयो । ';
@@ -71,6 +79,8 @@ $lang['profna']                = 'यो विकिले यो प्रो
 $lang['profnochange']          = 'केहि  परिवर्तन छैन , केहि गर्नु छैन ।';
 $lang['profnoempty']           = 'खाली नाम वा इमेल ठेगानालाई अनुमति छैन ।';
 $lang['profchanged']           = 'प्रयोगकर्ताको प्रफाइल सफलरुपमा परिवर्तन भयो ।';
+$lang['profnodelete']          = 'यो विकिले प्रयोगकर्ताहरू हटाउन समर्थन गर्दैन';
+$lang['profdeleteuser']        = 'खाता मेट्नुहोस';
 $lang['pwdforget']             = 'आफ्नो पासवर्ड भुल्नु भयो ? नयाँ हासिल गर्नुहोस् ';
 $lang['resendna']              = 'यो विकिबाट प्रवेशशव्द पठाउन समर्थित छैन ।';
 $lang['resendpwd']             = 'नयाँ  प्रवेशशव्द पठाउनुहोस् ';
@@ -80,21 +90,21 @@ $lang['resendpwdconfirm']      = 'तपाईको इमेलमा कन
 $lang['resendpwdsuccess']      = 'तपाईको प्रवेशशव्द इमेलबाट पठाइएको छ। ';
 $lang['license']               = 'खुलाइएको बाहेक, यस विकिका विषयवस्तुहरु निम्त प्रमाण द्वारा प्रमाणिक गरिएको छ।';
 $lang['licenseok']             = 'नोट: यस पृष्ठ सम्पादन गरी तपाईले आफ्नो विषयवस्तु तलको प्रमाण पत्र अन्तर्गत प्रमाणिक गर्न राजी हुनु हुनेछ ।';
-$lang['txt_upload']            = 'अपलोड गर्नलाई फाइल छा्न्नुहो्स्';
-$lang['txt_filename']          = 'अर्को रुपमा अपलोड गर्नुहोस् (ऐच्छिक)';
+$lang['txt_upload']            = 'अपलोड गर्नलाई फाइल छा्न्नुहो्स्:';
+$lang['txt_filename']          = 'अर्को रुपमा अपलोड गर्नुहोस् (ऐच्छिक):';
 $lang['txt_overwrt']           = 'रहेको उहि नामको फाइललाई मेटाउने';
-$lang['lockedby']              = 'अहिले ताल्चा लगाइएको';
+$lang['lockedby']              = 'अहिले ताल्चा लगाइएको:';
 $lang['lockexpire']            = 'ताल्चा अवधि सकिने :';
 $lang['js']['willexpire']      = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
 $lang['js']['notsavedyet']     = 'तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।';
 $lang['js']['keepopen']        = 'छनौटमा विन्डो खुला राख्नुहोस् ';
 $lang['js']['hidedetails']     = 'जानकारी लुकाउनु होस् ';
+$lang['js']['mediaclose']      = 'बन्द गर्ने';
 $lang['js']['nosmblinks']      = 'विन्डोहरु लिङ्क गर्दा माइक्रो सफ्ट एक्सप्लोररमामात्र  काम साझा हुन्छ । तर कपि गर्न र टास्न मिल्छ।   ';
 $lang['js']['del_confirm']     = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
 $lang['rssfailed']             = 'यो फिड लिइ आउदा गल्ति भयो ।';
 $lang['nothingfound']          = 'केहि पनि भेटिएन ।';
 $lang['mediaselect']           = 'मिडिया फाइलहरू ';
-$lang['fileupload']            = 'मिडिया फाइल अपलोड ';
 $lang['uploadsucc']            = 'अपलोड सफल ';
 $lang['uploadfail']            = 'अपलोड असफल । सायद गलत अनुमति । ';
 $lang['uploadwrong']           = 'अपलोड असमर्थित । फाइल एक्सटेन्सन अमान्य।  ';
@@ -123,9 +133,9 @@ $lang['yours']                 = 'तपाईको संस्करण';
 $lang['diff']                  = 'हालको संस्करण सँगको भिन्नता';
 $lang['diff2']                 = 'रोजिएका संस्करण वीचका भिन्नताहरु ';
 $lang['line']                  = 'हरफ';
-$lang['breadcrumb']            = 'छुट्ट्याउनुहोस् ';
-$lang['youarehere']            = 'तपाई यहा हुनुहुन्छ';
-$lang['lastmod']               = 'अन्तिम पटक सच्याइएको';
+$lang['breadcrumb']            = 'छुट्ट्याउनुहोस् :';
+$lang['youarehere']            = 'तपाई यहा हुनुहुन्छ:';
+$lang['lastmod']               = 'अन्तिम पटक सच्याइएको:';
 $lang['by']                    = 'द्वारा ';
 $lang['deleted']               = 'हटाइएको';
 $lang['created']               = 'निर्माण गरिएको';
@@ -154,21 +164,19 @@ $lang['qb_media']              = 'तस्विर र अरु फाइल
 $lang['qb_sig']                = 'हस्ताक्षर थप्नुहोस् ';
 $lang['qb_smileys']            = 'स्माइलीहरु ';
 $lang['qb_chars']              = 'विशेष वर्णहरु ';
-$lang['admin_register']        = 'नयाँ प्रयोगकर्ता थप्नुहोस् ';
 $lang['metaedit']              = 'मेटाडेटा सम्पादन गर्नुहोस्';
 $lang['metasaveerr']           = 'मेटाडाटा लेखन असफल';
 $lang['metasaveok']            = 'मेटाडाटा वचत भयो ';
-$lang['btn_img_backto']            = 'फिर्ता%s';
-$lang['img_title']             = 'शिर्षक';
-$lang['img_caption']           = 'निम्न लेख';
-$lang['img_date']              = 'मिति';
-$lang['img_fname']             = 'फाइलनाम';
-$lang['img_fsize']             = 'आकार';
-$lang['img_artist']            = 'चित्रकार';
-$lang['img_copyr']             = 'सर्वाधिकार';
-$lang['img_format']            = 'ढाचा';
-$lang['img_camera']            = 'क्यामेरा';
-$lang['img_keywords']          = 'खोज शब्द';
+$lang['img_title']             = 'शिर्षक:';
+$lang['img_caption']           = 'निम्न लेख:';
+$lang['img_date']              = 'मिति:';
+$lang['img_fname']             = 'फाइलनाम:';
+$lang['img_fsize']             = 'आकार:';
+$lang['img_artist']            = 'चित्रकार:';
+$lang['img_copyr']             = 'सर्वाधिकार:';
+$lang['img_format']            = 'ढाचा:';
+$lang['img_camera']            = 'क्यामेरा:';
+$lang['img_keywords']          = 'खोज शब्द:';
 $lang['authtempfail']          = 'प्रयोगकर्ता प्रामाणिकरण अस्थाइरुपमा अनुपलब्ध छ। यदि यो समस्या रहि रहेमा तपाईको  विकि एड्मिनलाई खवर गर्नुहोला ।';
 $lang['i_chooselang']          = 'भाषा छान्नुहोस् ';
 $lang['i_installer']           = 'DokuWiki  स्थापक';
@@ -192,3 +200,5 @@ $lang['i_pol1']                = 'Public विकि (पठन सवैका
 $lang['i_pol2']                = 'बन्द विकि (पठन , लेखन, अपलोड ) दर्ता भएका प्रयोगकर्ताका लागि मात्र ।';
 $lang['i_retry']               = 'पुन: प्रयास गर्नुहोस् ';
 $lang['recent_global']         = 'तपाई अहिले <b>%s</b> नेमस्पेस भित्र भएका परिवर्तन हेर्दैहुनुहुन्छ। तपाई <a href="%s">पुरै विकिमा भएको परिवर्तन हेर्न सक्नुहुन्छ</a>.';
+$lang['email_signature_text'] = 'यो पत्र DokuWiki ले, मा तयार पारेको हो ।
+@DOKUWIKIURL@';
