@@ -2,7 +2,9 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Harriet Neitz <harrietneitz@gmail.com>
+ * @author mark prins <mprins@users.sf.net>
  * @author François Kooman <fkooman.tuxed.net>
  * @author Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
  * @author Riny Heijdendael <riny@heijdendael.nl>
@@ -17,33 +19,38 @@
  * @author Jeroen
  * @author Ricardo Guijt <ricardoguijt@gmail.com>
  * @author Gerrit <klapinklapin@gmail.com>
- * @author mprins <mprins@users.sf.net>
- * @author Gerrit Uitslag <klapinklapin@gmail.com>
- * @author Klap-in <klapinklapin@gmail.com>
  * @author Remon <no@email.local>
  * @author gicalle <gicalle@hotmail.com>
  * @author Rene <wllywlnt@yahoo.com>
+ * @author Johan Vervloet <johan.vervloet@gmail.com>
+ * @author Mijndert <mijndert@mijndertstuij.nl>
+ * @author Johan Wijnker <johan@wijnker.eu>
+ * @author Hugo Smet <hugo.smet@scarlet.be>
+ * @author Wesley de Weerd <wesleytiel@gmail.com>
+ * @author Sjoerd <sjoerd@sjomar.eu>
+ * @author Joachim David <joa_david@hotmail.com>
+ * @author stafmans <dokuwiki@stafmans.net>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '„';
+$lang['doublequoteopening']    = '“';
 $lang['doublequoteclosing']    = '”';
-$lang['singlequoteopening']    = '‚';
+$lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
-$lang['apostrophe']            = '\'';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Pagina aanpassen';
-$lang['btn_source']            = 'Toon broncode';
+$lang['btn_source']            = 'Toon bronpagina';
 $lang['btn_show']              = 'Toon pagina';
 $lang['btn_create']            = 'Maak deze pagina aan';
 $lang['btn_search']            = 'Zoeken';
 $lang['btn_save']              = 'Opslaan';
 $lang['btn_preview']           = 'Voorbeeld';
 $lang['btn_top']               = 'Terug naar boven';
-$lang['btn_newer']             = '<< recenter';
+$lang['btn_newer']             = '<< nieuwer';
 $lang['btn_older']             = 'ouder >>';
 $lang['btn_revs']              = 'Oude revisies';
 $lang['btn_recent']            = 'Recente aanpassingen';
-$lang['btn_upload']            = 'Upload';
+$lang['btn_upload']            = 'Uploaden';
 $lang['btn_cancel']            = 'Annuleren';
 $lang['btn_index']             = 'Index';
 $lang['btn_secedit']           = 'Aanpassen';
@@ -54,7 +61,6 @@ $lang['btn_update']            = 'Bijwerken';
 $lang['btn_delete']            = 'Verwijder';
 $lang['btn_back']              = 'Terug';
 $lang['btn_backlink']          = 'Referenties';
-$lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
 $lang['btn_subscribe']         = 'Inschrijven wijzigingen';
 $lang['btn_profile']           = 'Profiel aanpassen';
 $lang['btn_reset']             = 'Wissen';
@@ -69,7 +75,7 @@ $lang['btn_media']             = 'Mediabeheerder';
 $lang['btn_deleteuser']        = 'Verwijder mijn account';
 $lang['btn_img_backto']        = 'Terug naar %s';
 $lang['btn_mediaManager']      = 'In mediabeheerder bekijken';
-$lang['loggedinas']            = 'Ingelogd als';
+$lang['loggedinas']            = 'Ingelogd als:';
 $lang['user']                  = 'Gebruikersnaam';
 $lang['pass']                  = 'Wachtwoord';
 $lang['newpass']               = 'Nieuw wachtwoord';
@@ -84,42 +90,9 @@ $lang['badpassconfirm']        = 'Sorry, het wachtwoord was onjuist';
 $lang['minoredit']             = 'Kleine wijziging';
 $lang['draftdate']             = 'Concept automatisch opgeslagen op';
 $lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie-informatie was verouderd, volledige pagina geladen.';
-$lang['regmissing']            = 'Vul alle velden in';
-$lang['reguexists']            = 'Er bestaat al een gebruiker met deze loginnaam.';
-$lang['regsuccess']            = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
-$lang['regsuccess2']           = 'De gebruiker is aangemaakt.';
-$lang['regmailfail']           = 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem contact op met de beheerder!';
-$lang['regbadmail']            = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
-$lang['regbadpass']            = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
-$lang['regpwmail']             = 'Je DokuWiki wachtwoord';
-$lang['reghere']               = 'Je hebt nog geen account? Vraag er eentje aan';
-$lang['profna']                = 'Deze wiki ondersteunt geen profielwijzigingen';
-$lang['profnochange']          = 'Geen wijzigingen, niets gedaan';
-$lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet toegestaan';
-$lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
-$lang['profnodelete']          = 'Deze wiki heeft biedt geen ondersteuning voor verwijdering van gebruikers';
-$lang['profdeleteuser']        = 'Verwijder gebruiker';
-$lang['profdeleted']           = 'Uw gebruikersaccount is verwijderd van deze wiki';
-$lang['profconfdelete']        = 'Ik wil mijn gebruikersaccount verwijderen van deze wiki. <br/> Deze actie kan niet ongedaan gemaakt worden.';
-$lang['profconfdeletemissing'] = 'Bevestigingsvinkje niet gezet';
-$lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
-$lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
-$lang['resendpwd']             = 'Nieuw wachtwoord bepalen voor';
-$lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
-$lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
-$lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
-$lang['resendpwdconfirm']      = 'Een bevestigingslink is per e-mail verzonden.';
-$lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden.';
-$lang['license']               = 'Tenzij anders vermeld valt de inhoud van deze wiki onder de volgende licentie:';
-$lang['licenseok']             = 'Let op: Door deze pagina aan te passen geef je de inhoud vrij onder de volgende licentie:';
-$lang['searchmedia']           = 'Bestandsnaam zoeken:';
-$lang['searchmedia_in']        = 'Zoek in %s';
-$lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
-$lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
-$lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
-$lang['maxuploadsize']         = 'Max %s per bestand';
-$lang['lockedby']              = 'Momenteel in gebruik door';
-$lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
+$lang['searchcreatepage']      = 'Als je niet hebt gevonden wat je zocht, kun je de pagina %s, vernoemd naar je query, aanmaken of bewerken.';
+$lang['search_fullresults']    = 'Fulltext resultaten';
+$lang['js']['search_toggle_tools'] = 'Schakel zoek gereedschappen aan/uit';
 $lang['js']['willexpire']      = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
 $lang['js']['notsavedyet']     = 'Nog niet bewaarde wijzigingen zullen verloren gaan.
 Weet je zeker dat je wilt doorgaan?';
@@ -163,10 +136,59 @@ $lang['js']['media_done_btn']  = 'Klaar';
 $lang['js']['media_drop']      = 'Sleep bestanden hierheen om ze te uploaden';
 $lang['js']['media_cancel']    = 'Verwijderen';
 $lang['js']['media_overwrt']   = 'Bestaande bestanden overschrijven';
+$lang['search_exact_match']    = 'Exacte overeenkomst';
+$lang['search_starts_with']    = 'Begint met';
+$lang['search_ends_with']      = 'Eindigt op';
+$lang['search_contains']       = 'Bevat';
+$lang['search_custom_match']   = 'Maatwerk';
+$lang['search_any_ns']         = '(Iedere) Willekeurige namespace';
+$lang['search_any_time']       = 'Wanneer dan ook';
+$lang['search_past_7_days']    = 'Vorige week';
+$lang['search_past_month']     = 'Vorige maand';
+$lang['search_past_year']      = 'Vorig jaar';
+$lang['search_sort_by_hits']   = 'Sorteer op hits';
+$lang['search_sort_by_mtime']  = 'Sorteer op laatst gewijzigd';
+$lang['regmissing']            = 'Vul alle velden in';
+$lang['reguexists']            = 'Er bestaat al een gebruiker met deze loginnaam.';
+$lang['regsuccess']            = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
+$lang['regsuccess2']           = 'De gebruiker is aangemaakt.';
+$lang['regfail']               = 'Gebruiker kon niet aangemaakt worden.';
+$lang['regmailfail']           = 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem contact op met de beheerder!';
+$lang['regbadmail']            = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
+$lang['regbadpass']            = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
+$lang['regpwmail']             = 'Je DokuWiki wachtwoord';
+$lang['reghere']               = 'Je hebt nog geen account? Vraag er eentje aan';
+$lang['profna']                = 'Deze wiki ondersteunt geen profielwijzigingen';
+$lang['profnochange']          = 'Geen wijzigingen, niets gedaan';
+$lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet toegestaan';
+$lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
+$lang['profnodelete']          = 'Deze wiki heeft biedt geen ondersteuning voor verwijdering van gebruikers';
+$lang['profdeleteuser']        = 'Verwijder gebruiker';
+$lang['profdeleted']           = 'Uw gebruikersaccount is verwijderd van deze wiki';
+$lang['profconfdelete']        = 'Ik wil mijn gebruikersaccount verwijderen van deze wiki. <br/> Deze actie kan niet ongedaan gemaakt worden.';
+$lang['profconfdeletemissing'] = 'Bevestigingsvinkje niet gezet';
+$lang['proffail']              = 'Gebruikersprofiel werd niet bijgewerkt.';
+$lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
+$lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
+$lang['resendpwd']             = 'Nieuw wachtwoord bepalen voor';
+$lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
+$lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
+$lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
+$lang['resendpwdconfirm']      = 'Een bevestigingslink is per e-mail verzonden.';
+$lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden.';
+$lang['license']               = 'Tenzij anders vermeld valt de inhoud van deze wiki onder de volgende licentie:';
+$lang['licenseok']             = 'Let op: Door deze pagina aan te passen geef je de inhoud vrij onder de volgende licentie:';
+$lang['searchmedia']           = 'Bestandsnaam zoeken:';
+$lang['searchmedia_in']        = 'Zoek in %s';
+$lang['txt_upload']            = 'Selecteer een bestand om te uploaden:';
+$lang['txt_filename']          = 'Vul nieuwe naam in (optioneel):';
+$lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
+$lang['maxuploadsize']         = 'Max %s per bestand';
+$lang['lockedby']              = 'Momenteel in gebruik door:';
+$lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op:';
 $lang['rssfailed']             = 'Er is een fout opgetreden bij het ophalen van de feed: ';
 $lang['nothingfound']          = 'Er werd niets gevonden.';
 $lang['mediaselect']           = 'Bestandsselectie';
-$lang['fileupload']            = 'Bestandsupload';
 $lang['uploadsucc']            = 'Upload geslaagd';
 $lang['uploadfail']            = 'Upload mislukt. Misschien verkeerde permissies?';
 $lang['uploadwrong']           = 'Upload mislukt. Deze bestandsextensie is verboden!';
@@ -206,9 +228,9 @@ $lang['difflastrev']           = 'Laatste revisie';
 $lang['diffbothprevrev']       = 'Beide kanten vorige revisie';
 $lang['diffbothnextrev']       = 'Beide kanten volgende revisie';
 $lang['line']                  = 'Regel';
-$lang['breadcrumb']            = 'Spoor';
-$lang['youarehere']            = 'Je bent hier';
-$lang['lastmod']               = 'Laatst gewijzigd';
+$lang['breadcrumb']            = 'Spoor:';
+$lang['youarehere']            = 'Je bent hier:';
+$lang['lastmod']               = 'Laatst gewijzigd:';
 $lang['by']                    = 'door';
 $lang['deleted']               = 'verwijderd';
 $lang['created']               = 'aangemaakt';
@@ -257,22 +279,21 @@ $lang['qb_sig']                = 'Handtekening invoegen';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Speciale tekens';
 $lang['upperns']               = 'Spring naar bovenliggende namespace';
-$lang['admin_register']        = 'Nieuwe gebruiker toevoegen';
 $lang['metaedit']              = 'Metadata wijzigen';
 $lang['metasaveerr']           = 'Schrijven van metadata mislukt';
 $lang['metasaveok']            = 'Metadata bewaard';
-$lang['img_title']             = 'Titel';
-$lang['img_caption']           = 'Bijschrift';
-$lang['img_date']              = 'Datum';
-$lang['img_fname']             = 'Bestandsnaam';
-$lang['img_fsize']             = 'Grootte';
-$lang['img_artist']            = 'Fotograaf';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formaat';
-$lang['img_camera']            = 'Camera';
-$lang['img_keywords']          = 'Trefwoorden';
-$lang['img_width']             = 'Breedte';
-$lang['img_height']            = 'Hoogte';
+$lang['img_title']             = 'Titel:';
+$lang['img_caption']           = 'Bijschrift:';
+$lang['img_date']              = 'Datum:';
+$lang['img_fname']             = 'Bestandsnaam:';
+$lang['img_fsize']             = 'Grootte:';
+$lang['img_artist']            = 'Fotograaf:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formaat:';
+$lang['img_camera']            = 'Camera:';
+$lang['img_keywords']          = 'Trefwoorden:';
+$lang['img_width']             = 'Breedte:';
+$lang['img_height']            = 'Hoogte:';
 $lang['subscr_subscribe_success'] = '%s is ingeschreven voor %s';
 $lang['subscr_subscribe_error'] = 'Fout bij inschrijven van %s voor %s';
 $lang['subscr_subscribe_noaddress'] = 'Er is geen e-mailadres gekoppeld aan uw account, u kunt daardoor niet worden ingeschreven.';
@@ -290,7 +311,6 @@ $lang['subscr_style_every']    = 'Email bij iedere wijziging';
 $lang['subscr_style_digest']   = 'Samenvattings-email met wijzigingen per pagina (elke %.2f dagen)';
 $lang['subscr_style_list']     = 'Lijst van veranderde pagina\'s sinds laatste email (elke %.2f dagen)';
 $lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
-$lang['authpwdexpire']         = 'Je wachtwoord verloopt in %d dagen, je moet het binnenkort veranderen';
 $lang['i_chooselang']          = 'Kies je taal';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Wikinaam';
@@ -300,6 +320,7 @@ $lang['i_problems']            = 'De installer vond problemen, hieronder aangege
 $lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://dokuwiki.org/install">Dokuwiki installatie-instructies</a>';
 $lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft je hosting provider deze uitgeschakeld?';
 $lang['i_phpver']              = 'PHP-versie <code>%s</code> is lager dan de vereiste <code>%s</code>. Upgrade PHP.';
+$lang['i_mbfuncoverload']      = 'Om DokuWiki te draaien moet mbstring.func_overload uitgeschakeld zijn in php.ini.';
 $lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. Pas de permissie-instellingen van deze directory aan.';
 $lang['i_confexists']          = '<code>%s</code> bestaat reeds';
 $lang['i_writeerr']            = 'Niet mogelijk om <code>%s</code> aan te maken. Controleer de directory/bestandspermissies en maak het bestand handmatig aan.';
@@ -314,7 +335,7 @@ $lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden al
 $lang['i_allowreg']            = 'Toestaan dat gebruikers zichzelf registeren';
 $lang['i_retry']               = 'Opnieuw';
 $lang['i_license']             = 'Kies a.u.b. een licentie die u voor uw inhoud wilt gebruiken:';
-$lang['i_license_none']        = 'Toon geen licentie informatie';
+$lang['i_license_none']        = 'Toon geen licentie-informatie';
 $lang['i_pop_field']           = 'Help ons om je DokuWiki ervaring te verbeteren';
 $lang['i_pop_label']           = 'Stuur eens per maand geanonimiseerde gebruiksstatistieken naar de Dokuwiki ontwikkelaars';
 $lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
@@ -349,7 +370,12 @@ $lang['media_perm_read']       = 'Sorry, u heeft niet voldoende rechten om besta
 $lang['media_perm_upload']     = 'Sorry, u heeft niet voldoende rechten om bestanden te uploaden.';
 $lang['media_update']          = 'Upload nieuwe versie';
 $lang['media_restore']         = 'Deze versie terugzetten';
+$lang['media_acl_warning']     = 'De lijst is mogelijk niet compleet door ACL beperkingen en verborgen pagina\'s.';
 $lang['currentns']             = 'Huidige namespace';
 $lang['searchresult']          = 'Zoekresultaat';
 $lang['plainhtml']             = 'Alleen HTML';
 $lang['wikimarkup']            = 'Wiki Opmaak';
+$lang['page_nonexist_rev']     = 'Pagina bestaat niet bij %s. Het is vervolgens aangemaakt bij <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Begrijp het niet bij parameter "%s".';
+$lang['email_signature_text']  = 'Deze mail werd gegenereerd door DokuWiki op
+@DOKUWIKIURL@';
