@@ -2,27 +2,28 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
  * @author Luis Fernando Enciso <lfenciso@certto.com.br>
  * @author Alauton/Loug
- * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Lucien Raven <lucienraven@yahoo.com.br>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Flávio Veras <flaviove@gmail.com>
  * @author Jeferson Propheta <jeferson.propheta@gmail.com>
- * @author jair.henrique@gmail.com
+ * @author jair.henrique <jair.henrique@gmail.com>
  * @author Luis Dantas <luis@dantas.com>
- * @author Luis Dantas <luisdantas@gmail.com>
- * @author Jair Henrique <jair.henrique@gmail.com>
  * @author Sergio Motta <sergio@cisne.com.br>
  * @author Isaias Masiero Filho <masiero@masiero.org>
- * @author Frederico Guimarães <frederico@teia.bio.br>
  * @author Balaco Baco <balacobaco@imap.cc>
  * @author Victor Westmann <victor.westmann@gmail.com>
  * @author Leone Lisboa Magevski <leone1983@gmail.com>
  * @author Dário Estevão <darioems@gmail.com>
  * @author Juliano Marconi Lanigra <juliano.marconi@gmail.com>
+ * @author Ednei <leuloch@gmail.com>
+ * @author Hudson FAS <hudsonfas@gmail.com>
+ * @author Guilherme Cardoso <guicardoso@gmail.com>
+ * @author Viliam Dias <viliamjr@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -54,7 +55,6 @@ $lang['btn_update']            = 'Atualizar';
 $lang['btn_delete']            = 'Excluir';
 $lang['btn_back']              = 'Voltar';
 $lang['btn_backlink']          = 'Links reversos';
-$lang['btn_backtomedia']       = 'Voltar à seleção do arquivo de mídia';
 $lang['btn_subscribe']         = 'Monitorar alterações';
 $lang['btn_profile']           = 'Atualizar o perfil';
 $lang['btn_reset']             = 'Limpar';
@@ -67,7 +67,9 @@ $lang['btn_register']          = 'Cadastre-se';
 $lang['btn_apply']             = 'Aplicar';
 $lang['btn_media']             = 'Gerenciador de mídias';
 $lang['btn_deleteuser']        = 'Remover minha conta';
-$lang['loggedinas']            = 'Identificado(a) como';
+$lang['btn_img_backto']        = 'Voltar para %s';
+$lang['btn_mediaManager']      = 'Ver no gerenciador de mídias';
+$lang['loggedinas']            = 'Identificado(a) como:';
 $lang['user']                  = 'Nome de usuário';
 $lang['pass']                  = 'Senha';
 $lang['newpass']               = 'Nova senha';
@@ -86,6 +88,7 @@ $lang['regmissing']            = 'Desculpe, mas você precisa preencher todos os
 $lang['reguexists']            = 'Desculpe, mas já existe um usuário com esse nome.';
 $lang['regsuccess']            = 'O usuário foi criado e a senha enviada para seu e-mail.';
 $lang['regsuccess2']           = 'O usuário foi criado.';
+$lang['regfail']               = 'Não foi possível criar esse usuário.';
 $lang['regmailfail']           = 'Aparentemente ocorreu um erro no envio da senha. Por favor, entre em contato com o administrador!';
 $lang['regbadmail']            = 'O endereço de e-mail fornecido é, aparentemente, inválido - se você acha que isso é um erro, entre em contato com o administrador';
 $lang['regbadpass']            = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
@@ -100,6 +103,7 @@ $lang['profdeleteuser']        = 'Excluir a conta';
 $lang['profdeleted']           = 'Sua conta de usuário foi excluída desse wiki';
 $lang['profconfdelete']        = 'Eu desejo remover minha conta dessa wiki. <br/> Essa ação não pode ser desfeita.';
 $lang['profconfdeletemissing'] = 'Caixa de confirmação não marcada';
+$lang['proffail']              = 'O perfil do usuário não foi atualizado.';
 $lang['pwdforget']             = 'Esqueceu sua senha? Solicite outra';
 $lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
 $lang['resendpwd']             = 'Definir a nova senha para';
@@ -112,12 +116,12 @@ $lang['license']               = 'Exceto onde for informado ao contrário, o con
 $lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
 $lang['searchmedia']           = 'Buscar arquivo:';
 $lang['searchmedia_in']        = 'Buscar em %s';
-$lang['txt_upload']            = 'Selecione o arquivo a ser enviado';
-$lang['txt_filename']          = 'Enviar como (opcional)';
+$lang['txt_upload']            = 'Selecione o arquivo a ser enviado:';
+$lang['txt_filename']          = 'Enviar como (opcional):';
 $lang['txt_overwrt']           = 'Substituir o arquivo existente';
 $lang['maxuploadsize']         = 'Tamanho máximo de %s por arquivo.';
-$lang['lockedby']              = 'Atualmente bloqueada por';
-$lang['lockexpire']            = 'O bloqueio expira em';
+$lang['lockedby']              = 'Atualmente bloqueada por:';
+$lang['lockexpire']            = 'O bloqueio expira em:';
 $lang['js']['willexpire']      = 'O seu bloqueio de edição deste página irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
 $lang['js']['notsavedyet']     = 'As alterações não salvas serão perdidas.
 Deseja realmente continuar?';
@@ -164,7 +168,6 @@ $lang['js']['media_overwrt']   = 'Sobrescrever arquivos existentes';
 $lang['rssfailed']             = 'Ocorreu um erro durante a atualização dessa fonte: ';
 $lang['nothingfound']          = 'Não foi encontrado nada.';
 $lang['mediaselect']           = 'Arquivos de mídia';
-$lang['fileupload']            = 'Envio de arquivo de mídia';
 $lang['uploadsucc']            = 'O envio foi efetuado com sucesso';
 $lang['uploadfail']            = 'Não foi possível enviar o arquivo. Será algum problema com as permissões?';
 $lang['uploadwrong']           = 'O envio foi bloqueado. Essa extensão de arquivo é proibida!';
@@ -198,10 +201,15 @@ $lang['difflink']              = 'Link para esta página de comparações';
 $lang['diff_type']             = 'Ver as diferenças:';
 $lang['diff_inline']           = 'Mescladas';
 $lang['diff_side']             = 'Lado a lado';
+$lang['diffprevrev']           = 'Revisão anterior';
+$lang['diffnextrev']           = 'Próxima revisão';
+$lang['difflastrev']           = 'Última revisão';
+$lang['diffbothprevrev']       = 'Ambos lados da revisão anterior';
+$lang['diffbothnextrev']       = 'Ambos lados da revisão seguinte';
 $lang['line']                  = 'Linha';
-$lang['breadcrumb']            = 'Visitou';
-$lang['youarehere']            = 'Você está aqui';
-$lang['lastmod']               = 'Última modificação';
+$lang['breadcrumb']            = 'Visitou:';
+$lang['youarehere']            = 'Você está aqui:';
+$lang['lastmod']               = 'Última modificação:';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'removida';
 $lang['created']               = 'criada';
@@ -250,24 +258,21 @@ $lang['qb_sig']                = 'Inserir assinatura';
 $lang['qb_smileys']            = 'Carinhas';
 $lang['qb_chars']              = 'Caracteres especiais';
 $lang['upperns']               = 'Pular para espaço de nomes acima';
-$lang['admin_register']        = 'Adicionar novo usuário';
 $lang['metaedit']              = 'Editar metadados';
 $lang['metasaveerr']           = 'Não foi possível escrever os metadados';
 $lang['metasaveok']            = 'Os metadados foram salvos';
-$lang['img_backto']            = 'Voltar para';
-$lang['img_title']             = 'Título';
-$lang['img_caption']           = 'Descrição';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nome do arquivo';
-$lang['img_fsize']             = 'Tamanho';
-$lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Direitos autorais';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Câmera';
-$lang['img_keywords']          = 'Palavras-chave';
-$lang['img_width']             = 'Largura';
-$lang['img_height']            = 'Altura';
-$lang['img_manager']           = 'Ver no gerenciador de mídias';
+$lang['img_title']             = 'Título:';
+$lang['img_caption']           = 'Descrição:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Nome do arquivo:';
+$lang['img_fsize']             = 'Tamanho:';
+$lang['img_artist']            = 'Fotógrafo:';
+$lang['img_copyr']             = 'Direitos autorais:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Câmera:';
+$lang['img_keywords']          = 'Palavras-chave:';
+$lang['img_width']             = 'Largura:';
+$lang['img_height']            = 'Altura:';
 $lang['subscr_subscribe_success'] = 'Adicionado %s à lista de monitoramentos de %s';
 $lang['subscr_subscribe_error'] = 'Ocorreu um erro na adição de %s à lista de monitoramentos de %s';
 $lang['subscr_subscribe_noaddress'] = 'Como não há nenhum endereço associado ao seu usuário, você não pode ser adicionado à lista de monitoramento';
@@ -285,7 +290,6 @@ $lang['subscr_style_every']    = 'um e-mail a cada modificação';
 $lang['subscr_style_digest']   = 'um agrupamento de e-mails com as mudanças para cada página (a cada %.2f dias)';
 $lang['subscr_style_list']     = 'uma lista de páginas modificadas desde o último e-mail (a cada %.2f dias)';
 $lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe ao administrador do Wiki.';
-$lang['authpwdexpire']         = 'Sua senha vai expirar em %d dias. Você deve mudá-la assim que for possível.';
 $lang['i_chooselang']          = 'Selecione o seu idioma';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome do Wiki';
@@ -296,6 +300,7 @@ $lang['i_modified']            = 'Por questões de segurança, esse script funci
 Você pode extrair novamente os arquivos do pacote original ou consultar as <a href="http://dokuwiki.org/install">instruções de instalação do DokuWiki</a>.';
 $lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. O seu host a mantém desabilitada por algum motivo?';
 $lang['i_phpver']              = 'A sua versão do PHP (<code>%s</code>) é inferior à necessária (<code>%s</code>). Você precisa atualizar a sua instalação do PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload precisa ser desabilitado no php.ini para executar o DokuWiki';
 $lang['i_permfail']            = 'O DokuWiki não tem permissão de escrita em <code>%s</code>. Você precisa corrigir as configurações de permissão nesse diretório!';
 $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É necessário checar as permissões de arquivos/diretórios e criar o arquivo manualmente.';
@@ -345,7 +350,12 @@ $lang['media_perm_read']       = 'Desculpe, mas você não tem privilégios sufi
 $lang['media_perm_upload']     = 'Desculpe, mas você não tem privilégios suficientes para enviar arquivos.';
 $lang['media_update']          = 'Enviar uma nova versão';
 $lang['media_restore']         = 'Restaurar esta versão';
+$lang['media_acl_warning']     = 'Essa lista pode não estar completa devido a restrições de ACL e páginas ocultas.';
 $lang['currentns']             = 'Domínio atual';
 $lang['searchresult']          = 'Resultado da Busca';
 $lang['plainhtml']             = 'HTML simples';
 $lang['wikimarkup']            = 'Marcação wiki';
+$lang['page_nonexist_rev']     = 'Página não encontrada em %s. Foi criada posteriormente em <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Impossível analisar em "%s".';
+$lang['email_signature_text']  = 'Essa mensagem foi gerada pelo DokuWiki em
+@DOKUWIKIURL@';
