@@ -2,13 +2,15 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Simon <sbx@protonmail.ch>
  * @author Jaka Kranjc <lynxlupodian@hotmail.com>
  * @author Boštjan Seničar <senicar@gmail.com>
  * @author Dejan Levec <webphp@gmail.com>
  * @author Gregor Skumavc (grega.skumavc@gmail.com)
  * @author Matej Urbančič (mateju@svn.gnome.org)
  * @author Matej Urbančič <mateju@svn.gnome.org>
+ * @author Jernej Vidmar <jernej.vidmar@vidmarboehm.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,7 +42,6 @@ $lang['btn_update']            = 'Posodobi';
 $lang['btn_delete']            = 'Izbriši';
 $lang['btn_back']              = 'Nazaj';
 $lang['btn_backlink']          = 'Povratne povezave';
-$lang['btn_backtomedia']       = 'Nazaj na izbiro predstavnih datotek';
 $lang['btn_subscribe']         = 'Urejanje naročnin';
 $lang['btn_profile']           = 'Posodobi profil';
 $lang['btn_reset']             = 'Ponastavi';
@@ -49,11 +50,13 @@ $lang['btn_draft']             = 'Uredi osnutek';
 $lang['btn_recover']           = 'Obnovi osnutek';
 $lang['btn_draftdel']          = 'Izbriši osnutek';
 $lang['btn_revert']            = 'Povrni';
-$lang['btn_register']          = 'Prijava';
+$lang['btn_register']          = 'Registracija';
 $lang['btn_apply']             = 'Uveljavi';
 $lang['btn_media']             = 'Urejevalnik predstavnih vsebin';
 $lang['btn_deleteuser']        = 'Odstrani račun';
-$lang['loggedinas']            = 'Prijava kot';
+$lang['btn_img_backto']        = 'Nazaj na %s';
+$lang['btn_mediaManager']      = 'Poglej v urejevalniku predstavnih vsebin';
+$lang['loggedinas']            = 'Prijava kot:';
 $lang['user']                  = 'Uporabniško ime';
 $lang['pass']                  = 'Geslo';
 $lang['newpass']               = 'Novo geslo';
@@ -84,6 +87,7 @@ $lang['profchanged']           = 'Uporabniški profil je uspešno posodobljen.';
 $lang['profnodelete']          = 'Ni omogočena podpora za brisanje uporabnikov.';
 $lang['profdeleteuser']        = 'Izbriši račun';
 $lang['profdeleted']           = 'Uporabniški račun je izbrisan.';
+$lang['profconfdeletemissing'] = 'Potrditveno okno ni označeno';
 $lang['pwdforget']             = 'Ali ste pozabili geslo? Pridobite si novo geslo.';
 $lang['resendna']              = 'DokuWiki ne podpira možnosti ponovnega pošiljanja gesel.';
 $lang['resendpwd']             = 'Nastavi novo geslo za';
@@ -96,11 +100,11 @@ $lang['license']               = 'V kolikor ni posebej določeno, je vsebina Wik
 $lang['licenseok']             = 'Opomba: z urejanjem vsebine strani, se strinjate z objavo pod pogoji dovoljenja:';
 $lang['searchmedia']           = 'Poišči ime datoteke:';
 $lang['searchmedia_in']        = 'Poišči v %s';
-$lang['txt_upload']            = 'Izberite datoteko za pošiljanje';
-$lang['txt_filename']          = 'Pošlji z imenom (izborno)';
+$lang['txt_upload']            = 'Izberite datoteko za pošiljanje:';
+$lang['txt_filename']          = 'Pošlji z imenom (izborno):';
 $lang['txt_overwrt']           = 'Prepiši obstoječo datoteko';
-$lang['lockedby']              = 'Trenutno je zaklenjeno s strani';
-$lang['lockexpire']            = 'Zaklep preteče ob';
+$lang['lockedby']              = 'Trenutno je zaklenjeno s strani:';
+$lang['lockexpire']            = 'Zaklep preteče ob:';
 $lang['js']['willexpire']      = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
 $lang['js']['notsavedyet']     = 'Neshranjene spremembe bodo izgubljene.';
 $lang['js']['searchmedia']     = 'Poišči datoteke';
@@ -144,7 +148,6 @@ $lang['js']['media_overwrt']   = 'Prepiši obstoječe datoteke';
 $lang['rssfailed']             = 'Prišlo je do napake med pridobivanjem vira: ';
 $lang['nothingfound']          = 'Ni najdenih predmetov.';
 $lang['mediaselect']           = 'Predstavne datoteke';
-$lang['fileupload']            = 'Pošiljanje predstavnih datotek';
 $lang['uploadsucc']            = 'Pošiljanje je bilo uspešno končano.';
 $lang['uploadfail']            = 'Pošiljanje je spodletelo. Morda so uporabljena neustrezna dovoljenja.';
 $lang['uploadwrong']           = 'Pošiljanje je zavrnjeno. Uporabljena pripona datoteke je prepovedana.';
@@ -178,10 +181,13 @@ $lang['difflink']              = 'Poveži s tem pogledom primerjave.';
 $lang['diff_type']             = 'Razlike:';
 $lang['diff_inline']           = 'V besedilu';
 $lang['diff_side']             = 'Eno ob drugem';
+$lang['diffprevrev']           = 'Prejšnja revizija';
+$lang['diffnextrev']           = 'Naslednja revizija';
+$lang['difflastrev']           = 'Zadnja revizija';
 $lang['line']                  = 'Vrstica';
-$lang['breadcrumb']            = 'Sled';
-$lang['youarehere']            = 'Trenutno dejavna stran';
-$lang['lastmod']               = 'Zadnja sprememba';
+$lang['breadcrumb']            = 'Sled:';
+$lang['youarehere']            = 'Trenutno dejavna stran:';
+$lang['lastmod']               = 'Zadnja sprememba:';
 $lang['by']                    = 'uporabnika';
 $lang['deleted']               = 'odstranjena';
 $lang['created']               = 'ustvarjena';
@@ -230,24 +236,21 @@ $lang['qb_sig']                = 'Vstavi podpis';
 $lang['qb_smileys']            = 'Smeški';
 $lang['qb_chars']              = 'Posebni znaki';
 $lang['upperns']               = 'skoči na nadrejeni imenski prostor';
-$lang['admin_register']        = 'Dodaj novega uporabnika';
 $lang['metaedit']              = 'Uredi metapodatke';
 $lang['metasaveerr']           = 'Zapisovanje metapodatkov je spodletelo';
 $lang['metasaveok']            = 'Metapodatki so shranjeni';
-$lang['img_backto']            = 'Nazaj na';
-$lang['img_title']             = 'Naslov';
-$lang['img_caption']           = 'Opis';
-$lang['img_date']              = 'Datum';
-$lang['img_fname']             = 'Ime datoteke';
-$lang['img_fsize']             = 'Velikost';
-$lang['img_artist']            = 'Fotograf';
-$lang['img_copyr']             = 'Avtorska pravica';
-$lang['img_format']            = 'Zapis';
-$lang['img_camera']            = 'Fotoaparat';
-$lang['img_keywords']          = 'Ključne besede';
-$lang['img_width']             = 'Širina';
-$lang['img_height']            = 'Višina';
-$lang['img_manager']           = 'Poglej v urejevalniku predstavnih vsebin';
+$lang['img_title']             = 'Naslov:';
+$lang['img_caption']           = 'Opis:';
+$lang['img_date']              = 'Datum:';
+$lang['img_fname']             = 'Ime datoteke:';
+$lang['img_fsize']             = 'Velikost:';
+$lang['img_artist']            = 'Fotograf:';
+$lang['img_copyr']             = 'Avtorska pravica:';
+$lang['img_format']            = 'Zapis:';
+$lang['img_camera']            = 'Fotoaparat:';
+$lang['img_keywords']          = 'Ključne besede:';
+$lang['img_width']             = 'Širina:';
+$lang['img_height']            = 'Višina:';
 $lang['subscr_subscribe_success'] = 'Uporabniški račun %s je dodan na seznam naročnin na %s';
 $lang['subscr_subscribe_error'] = 'Napaka med dodajanjem %s na seznam naročnin na %s';
 $lang['subscr_subscribe_noaddress'] = 'S trenutnimi prijavnimi podatki ni povezanega elektronskega naslova, zato uporabniškega računa ni mogoče dodati na seznam naročnikov.';
@@ -289,6 +292,8 @@ $lang['i_allowreg']            = 'Dovoli uporabnikom vpis';
 $lang['i_retry']               = 'Ponovni poskus';
 $lang['i_license']             = 'Izbor dovoljenja objave vsebine:';
 $lang['i_license_none']        = 'Ne pokaži podrobnosti dovoljenja.';
+$lang['i_pop_field']           = 'Prosimo pomagajte nam izboljšati DokuWiki izkušnjo:';
+$lang['i_pop_label']           = 'Enkrat na mesec pošlji anonimne uporabniške podatke DokuWiki razvijalcem';
 $lang['recent_global']         = 'Trenutno so prikazane spremembe znotraj imenskega prostora <b>%s</b>. Mogoče si je ogledati tudi spremembe <a href="%s">celotnega sistema Wiki</a>.';
 $lang['years']                 = '%d let nazaj';
 $lang['months']                = '%d mesecev nazaj';
@@ -324,3 +329,6 @@ $lang['media_restore']         = 'Obnovi to različico';
 $lang['currentns']             = 'Trenutni imenski prostor';
 $lang['searchresult']          = 'Rezultati iskanja';
 $lang['plainhtml']             = 'Zapis HTML';
+$lang['wikimarkup']            = 'Oblikovni jezik Wiki';
+$lang['email_signature_text']  = 'Sporočilo je samodejno ustvarjeno na spletišču
+@DOKUWIKIURL@';
