@@ -13,7 +13,9 @@ $lang['binddn']      = 'DN of an optional bind user if anonymous bind is not suf
 $lang['bindpw']      = 'Password of above user';
 $lang['userscope']   = 'Limit search scope for user search';
 $lang['groupscope']  = 'Limit search scope for group search';
+$lang['userkey']     = 'Attribute denoting the username; must be consistent to userfilter.';
 $lang['groupkey']    = 'Group membership from any user attribute (instead of standard AD groups) e.g. group from department or telephone number';
+$lang['modPass']     = 'Can the LDAP password be changed via dokuwiki?';
 $lang['debug']       = 'Display additional debug information on errors';
 
 
@@ -21,3 +23,7 @@ $lang['deref_o_0']   = 'LDAP_DEREF_NEVER';
 $lang['deref_o_1']   = 'LDAP_DEREF_SEARCHING';
 $lang['deref_o_2']   = 'LDAP_DEREF_FINDING';
 $lang['deref_o_3']   = 'LDAP_DEREF_ALWAYS';
+
+$lang['referrals_o_-1'] = 'use default';
+$lang['referrals_o_0']  = 'don\'t follow referrals';
+$lang['referrals_o_1']  = 'follow referrals';
\ No newline at end of file
