@@ -1,12 +1,17 @@
 <?php
+
 /**
- * Catalan language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
  * @author Carles Bellver <carles.bellver@gmail.com>
  * @author carles.bellver@gmail.com
  * @author carles.bellver@cent.uji.es
  * @author Carles Bellver <carles.bellver@cent.uji.es>
  * @author daniel@6temes.cat
+ * @author controlonline.net <controlonline.net@gmail.com>
+ * @author Pauet <pauet@gmx.com>
+ * @author Àngel Pérez Beroy <aperezberoy@gmail.com>
+ * @author David Surroca <david.tb303@gmail.com>
  */
 $lang['menu']                  = 'Paràmetres de configuració';
 $lang['error']                 = 'Els paràmetres no s\'han pogut actualitzar per causa d\'un valor incorrecte Reviseu els canvis i torneu a enviar-los.<br />Els valors incorrectes es ressaltaran amb un marc vermell.';
@@ -56,7 +61,7 @@ $lang['breadcrumbs']           = 'Nombre d\'engrunes';
 $lang['youarehere']            = 'Camí d\'engrunes jeràrquic';
 $lang['fullpath']              = 'Mostra el camí complet de les pàgines al peu';
 $lang['typography']            = 'Substitucions tipogràfiques';
-$lang['dformat']               = 'Format de data (vg. la funció PHP <a href="http://www.php.net/strftime">strftime</a>)';
+$lang['dformat']               = 'Format de data (vg. la funció PHP <a href="http://php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Signatura';
 $lang['showuseras']            = 'Què cal visualitzar quan es mostra el darrer usuari que ha editat la pàgina';
 $lang['toptoclevel']           = 'Nivell superior per a la taula de continguts';
