@@ -1,17 +1,19 @@
 <?php
+
 /**
- * Danish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Kenneth Schack Banner <kescba@gmail.com>
+ * @author Jon Theil Nielsen <jontheil@gmail.com>
  * @author Lars Næsbye Christensen <larsnaesbye@stud.ku.dk>
  * @author Kalle Sommer Nielsen <kalle@php.net>
  * @author Esben Laursen <hyber@hyber.dk>
  * @author Harith <haj@berlingske.dk>
  * @author Daniel Ejsing-Duun <dokuwiki@zilvador.dk>
  * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
- * @author rasmus@kinnerup.com
- * @author Michael Pedersen subben@gmail.com
+ * @author rasmus <rasmus@kinnerup.com>
  * @author Mikael Lyngvig <mikael@lyngvig.org>
+ * @author Jacob Palm <mail@jacobpalm.dk>
  */
 $lang['menu']                  = 'Opsætningsindstillinger';
 $lang['error']                 = 'Indstillingerne blev ikke opdateret på grund af en ugyldig værdi, Gennemse venligst dine ændringer og gem dem igen.
@@ -38,8 +40,6 @@ $lang['_media']                = 'Medieindstillinger';
 $lang['_notifications']        = 'Notificeringsindstillinger';
 $lang['_advanced']             = 'Avancerede indstillinger';
 $lang['_network']              = 'Netværksindstillinger';
-$lang['_plugin_sufix']         = 'Udvidelsesindstillinger';
-$lang['_template_sufix']       = 'Skabelonindstillinger';
 $lang['_msg_setting_undefined'] = 'Ingen indstillingsmetadata.';
 $lang['_msg_setting_no_class'] = 'Ingen indstillingsklasse.';
 $lang['_msg_setting_no_default'] = 'Ingen standardværdi.';
@@ -63,7 +63,7 @@ $lang['breadcrumbs']           = 'Stilængde';
 $lang['youarehere']            = 'Hierarkisk sti';
 $lang['fullpath']              = 'Vis den fulde sti til siderne i bundlinjen';
 $lang['typography']            = 'Typografiske erstatninger';
-$lang['dformat']               = 'Datoformat (se PHP\'s <a href="http://www.php.net/strftime">strftime</a>-funktion)';
+$lang['dformat']               = 'Datoformat (se PHP\'s <a href="http://php.net/strftime">strftime</a>-funktion)';
 $lang['signature']             = 'Underskrift';
 $lang['showuseras']            = 'Hvad skal vises når den sidste bruger, der har ændret siden, fremstilles';
 $lang['toptoclevel']           = 'Øverste niveau for indholdsfortegnelse';
@@ -110,7 +110,6 @@ $lang['target____media']       = 'Målvindue for mediehenvisninger';
 $lang['target____windows']     = 'Målvindue til Windows-henvisninger';
 $lang['mediarevisions']        = 'Akvtivér media udgaver?';
 $lang['refcheck']              = 'Mediehenvisningerkontrol';
-$lang['refshow']               = 'Antal viste mediehenvisninger';
 $lang['gdlib']                 = 'Udgave af GD Lib';
 $lang['im_convert']            = 'Sti til ImageMagick\'s omdannerværktøj';
 $lang['jpg_quality']           = 'JPG komprimeringskvalitet (0-100)';
