@@ -1,15 +1,15 @@
 <?php
+
 /**
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * Esperantolanguage file
  *
+ * @author Kristjan SCHMIDT <kristjan.schmidt@googlemail.com>
  * @author Felipe Castro <fefcas@uol.com.br>
- * @author Felipe Castro <fefcas@gmail.com>
- * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
  * @author Felipo Kastro <fefcas@gmail.com>
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik pedersen@shaw.ca>
- * @author Erik Pedersen <erik.pedersen@shaw.ca>
- * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['menu']                  = 'Agordaj Difinoj';
 $lang['error']                 = 'La difinoj ne estas ĝisdatigitaj pro malvalida valoro: bonvolu revizii viajn ŝanĝojn kaj resubmeti ilin.
@@ -36,8 +36,6 @@ $lang['_notifications']        = 'Sciigaj agordoj';
 $lang['_syndication']          = 'Kunhavigaj agordoj';
 $lang['_advanced']             = 'Fakaj difinoj';
 $lang['_network']              = 'Difinoj por reto';
-$lang['_plugin_sufix']         = 'Difinoj por kromaĵoj';
-$lang['_template_sufix']       = 'Difinoj por ŝablonoj';
 $lang['_msg_setting_undefined'] = 'Neniu difinanta metadatumaro.';
 $lang['_msg_setting_no_class'] = 'Neniu difinanta klaso.';
 $lang['_msg_setting_no_default'] = 'Neniu apriora valoro.';
@@ -61,7 +59,7 @@ $lang['breadcrumbs']           = 'Nombro da paderoj';
 $lang['youarehere']            = 'Hierarkiaj paderoj';
 $lang['fullpath']              = 'Montri la kompletan padon de la paĝoj en la piedlinio';
 $lang['typography']            = 'Fari tipografiajn anstataŭigojn';
-$lang['dformat']               = 'Formato de datoj (vidu la PHP-an funkcion <a href="http://www.php.net/strftime">strftime</a>)';
+$lang['dformat']               = 'Formato de datoj (vidu la PHP-an funkcion <a href="http://php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Subskribo';
 $lang['showuseras']            = 'Kiel indiki la lastan redaktinton';
 $lang['toptoclevel']           = 'Supera nivelo por la enhavtabelo';
@@ -86,6 +84,7 @@ $lang['disableactions']        = 'Malebligi DokuWiki-ajn agojn';
 $lang['disableactions_check']  = 'Kontroli';
 $lang['disableactions_subscription'] = 'Aliĝi/Malaliĝi';
 $lang['disableactions_wikicode'] = 'Rigardi vikitekston/Eksporti fontotekston';
+$lang['disableactions_profile_delete'] = 'Forigi la propran konton';
 $lang['disableactions_other']  = 'Aliaj agoj (disigita per komoj)';
 $lang['auth_security_timeout'] = 'Sekureca tempolimo por aŭtentigo (sekundoj)';
 $lang['securecookie']          = 'Ĉu kuketoj difinitaj per HTTPS sendiĝu de la foliumilo nur per HTTPS? Malebligu tiun ĉi opcion kiam nur la ensaluto al via vikio estas sekurigita per SSL, sed foliumado de la vikio estas farita malsekure.';
@@ -108,7 +107,6 @@ $lang['target____media']       = 'Parametro "target" (celo) por aŭdvidaĵaj lig
 $lang['target____windows']     = 'Parametro "target" (celo) por Vindozaj ligiloj';
 $lang['mediarevisions']        = 'Ĉu ebligi reviziadon de aŭdvidaĵoj?';
 $lang['refcheck']              = 'Kontrolo por referencoj al aŭdvidaĵoj';
-$lang['refshow']               = 'Nombro da referencoj al aŭdvidaĵoj por montri';
 $lang['gdlib']                 = 'Versio de GD-Lib';
 $lang['im_convert']            = 'Pado al la konvertilo de ImageMagick';
 $lang['jpg_quality']           = 'Kompaktiga kvalito de JPG (0-100)';
@@ -127,6 +125,8 @@ $lang['rss_content']           = 'Kion montri en la XML-aj novaĵ-flueroj?';
 $lang['rss_update']            = 'Intertempo por ĝisdatigi XML-an novaĵ-fluon (sek.)';
 $lang['rss_show_summary']      = 'XML-a novaĵ-fluo montras resumon en la titolo';
 $lang['rss_media']             = 'Kiaj ŝangoj estu montrataj en la XML-fluo?';
+$lang['rss_media_o_both']      = 'ambaŭ';
+$lang['rss_media_o_pages']     = 'paĝoj';
 $lang['updatecheck']           = 'Ĉu kontroli aktualigojn kaj sekurecajn avizojn? DokuWiki bezonas kontakti update.dokuwiki.org por tiu ĉi trajto.';
 $lang['userewrite']            = 'Uzi netajn URL-ojn';
 $lang['useslash']              = 'Uzi frakcistrekon kiel disigsignaĵon por nomspacoj en URL-oj';
@@ -137,10 +137,10 @@ $lang['autoplural']            = 'Kontroli pluralajn formojn en ligiloj';
 $lang['compression']           = 'Kompaktigmetodo por arkivaj dosieroj';
 $lang['gzip_output']           = 'Uzi gzip-an enhav-enkodigon por XHTML';
 $lang['compress']              = 'Kompaktigi CSS-ajn kaj ĵavaskriptajn elmetojn';
-$lang['cssdatauri']            = 'Grandeco en bitokoj, ĝis kiom en CSS-dosieroj referencitaj bildoj enmetiĝu rekte en la stilfolion por malgrandigi vanan HTTP-kapan trafikon. Tiu tekniko ne funkcias en IE 7 aŭ pli frua!
+$lang['cssdatauri']            = 'Grandeco en bitokoj, ĝis kiom en CSS-dosieroj referencitaj bildoj enmetiĝu rekte en la stilfolion por malgrandigi vanan HTTP-kapan trafikon.
 <code>400</code> ĝis <code>600</code> bitokoj estas bona grandeco. Indiku <code>0</code> por malebligi enmeton.';
 $lang['send404']               = 'Sendi la mesaĝon "HTTP 404/Paĝo ne trovita" por ne ekzistantaj paĝoj';
-$lang['broken_iua']            = 'Ĉu la funkcio "ignore_user_abort" difektas en via sistemo? Tio povus misfunkciigi la serĉindekson. IIS+PHP/CGI estas konata kiel fuŝaĵo. Vidu <a href="http://bugs.splitbrain.org/?do=details&task_id=852&">Cimon 852</a> por pli da informoj.';
+$lang['broken_iua']            = 'Ĉu la funkcio "ignore_user_abort" difektas en via sistemo? Tio povus misfunkciigi la serĉindekson. IIS+PHP/CGI estas konata kiel fuŝaĵo. Vidu <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Cimon 852</a> por pli da informoj.';
 $lang['xsendfile']             = 'Ĉu uzi la kaplinion X-Sendfile por ebligi al la retservilo liveri fiksajn dosierojn? Via retservilo subtenu tion.';
 $lang['renderer_xhtml']        = 'Prezentilo por la ĉefa vikia rezulto (xhtml)';
 $lang['renderer__core']        = '%s (DokuWiki-a kerno)';
