@@ -12,6 +12,7 @@
  * @author AmirH Hassaneini <mytechmix@gmail.com>
  * @author Mohmmad Razavi <sepent@gmail.com>
  * @author Masoud Sadrnezhaad <masoud@sadrnezhaad.ir>
+ * @author sam01 <m.sajad079@gmail.com>
  */
 $lang['menu']                  = 'تنظیمات پیکر‌بندی';
 $lang['error']                 = 'به دلیل ایراد در مقادیر وارد شده، تنظیمات اعمال نشد، خواهشمندیم تغییرات را مجددن کنترل نمایید و دوباره ارسال کنید.<br/> مقادیر مشکل‌دار با کادر قرمز مشخص شده‌اند.';
@@ -70,7 +71,7 @@ $lang['maxseclevel']           = 'بیش‌ترین سطح ویرایش بخش
 $lang['camelcase']             = 'از «حالت شتری» (CamelCase) برای پیوندها استفاده شود';
 $lang['deaccent']              = 'تمیز کردن نام صفحات';
 $lang['useheading']            = 'استفاده از اولین عنوان برای نام صفحه';
-$lang['sneaky_index']          = 'به طور پیش‌فرض، DokuWiki در فهرست تمامی فضای‌نام‌ها را نمایش می‌دهد. فعال کردن این گزینه، مواردی را که کاربر حق خواندنشان را ندارد مخفی می‌کند. این گزینه ممکن است باعث دیده نشدن زیرفضای‌نام‌هایی شود که دسترسی خواندن به آن‌ها وجود دارد. و ممکن است باعث شود که فهرست در حالاتی از دسترسی‌ها، غیرقابل استفاده شود.';
+$lang['sneaky_index']          = 'به طور پیش‌فرض، دوکوویکی در فهرست تمامی فضای‌نام‌ها را نمایش می‌دهد. فعال کردن این گزینه، مواردی را که کاربر حق خواندنشان را ندارد مخفی می‌کند. این گزینه ممکن است باعث دیده نشدن زیرفضای‌نام‌هایی شود که دسترسی خواندن به آن‌ها وجود دارد. و ممکن است باعث شود که فهرست در حالاتی از دسترسی‌ها، غیرقابل استفاده شود.';
 $lang['hidepages']             = 'مخفی کردن صفحات با فرمت زیر (از عبارات منظم استفاده شود)';
 $lang['useacl']                = 'استفاده از مدیریت دسترسی‌ها';
 $lang['autopasswd']            = 'ایجاد خودکار گذرواژه‌ها';
@@ -81,7 +82,7 @@ $lang['superuser']             = 'کاربر اصلی - گروه، کاربر ی
 $lang['manager']               = 'مدیر - گروه، کاربر یا لیستی که توسط ویرگول جدا شده از کاربرها و گروه‌ها (مثل user1,@group1,user2) با دسترسی‌های خاص به بخش‌های متفاوت';
 $lang['profileconfirm']        = 'تغییرات پروفایل با وارد کردن گذرواژه تایید شود';
 $lang['rememberme']            = 'امکان ورود دایم، توسط کوکی، وجود داشته باشد (مرا به خاطر بسپار)';
-$lang['disableactions']        = 'غیرفعال کردن فعالیت‌های DokuWiki';
+$lang['disableactions']        = 'غیرفعال کردن فعالیت‌های دوکوویکی';
 $lang['disableactions_check']  = 'بررسی';
 $lang['disableactions_subscription'] = 'عضویت/عدم عضویت';
 $lang['disableactions_wikicode'] = 'نمایش سورس/برون‌بری خام';
@@ -128,7 +129,7 @@ $lang['rss_content']           = 'چه چیزی در تکه‌های خوراک
 $lang['rss_update']            = 'زمان به روز رسانی خوراک به ثانیه';
 $lang['rss_show_summary']      = 'خوراک مختصری از مطلب را در عنوان نمایش دهد';
 $lang['rss_media']             = 'چه نوع تغییراتی باید در خوراک XML لیست شود؟';
-$lang['updatecheck']           = 'هشدارهای به روز رسانی و امنیتی بررسی شود؟ برای این‌کار DokuWiki با سرور update.dokuwiki.org تماس خواهد گرفت.';
+$lang['updatecheck']           = 'هشدارهای به روز رسانی و امنیتی بررسی شود؟ برای این‌کار دوکوویکی با سرور update.dokuwiki.org تماس خواهد گرفت.';
 $lang['userewrite']            = 'از زیباکننده‌ی آدرس‌ها استفاده شود';
 $lang['useslash']              = 'از اسلش «/» برای جداکننده‌ی آدرس فضای‌نام‌ها استفاده شود';
 $lang['sepchar']               = 'کلمه‌ی جداکننده‌ی نام صفحات';
@@ -145,7 +146,7 @@ $lang['xsendfile']             = 'استفاده از هدر X-Sendfile، تا 
 $lang['renderer_xhtml']        = 'مفسری که برای خروجی اصلی ویکی استفاده شود';
 $lang['renderer__core']        = '%s (هسته‌ی dokuwiki)';
 $lang['renderer__plugin']      = '%s (افزونه)';
-$lang['dnslookups']            = 'DokuWiki نام هاست ها را برای آدرسهای IP یِ صفحات ویرایشی کاربران ، جستجو می کند. اگر یک سرور DNS کند یا نا کارامد دارید یا این ویژگی را نمی خواهید ، این گزینه را غیر فعال کنید.';
+$lang['dnslookups']            = 'دوکوویکی نام هاست ها را برای آدرسهای آی‌پی‌های صفحات ویرایشی کاربران ، جستجو می کند. اگر یک سرور DNS کند یا نا کارامد دارید یا این ویژگی را نمی خواهید ، این گزینه را غیر فعال کنید.';
 $lang['proxy____host']         = 'آدرس سرور پروکسی';
 $lang['proxy____port']         = 'پورت پروکسی';
 $lang['proxy____user']         = 'نام کاربری پروکسی';
