@@ -69,7 +69,7 @@ $lang['tocminheads']           = '目次を生成するための最小見出し
 $lang['maxtoclevel']           = '目次 表示限度見出し';
 $lang['maxseclevel']           = '編集可能見出し';
 $lang['camelcase']             = 'キャメルケースリンク';
-$lang['deaccent']              = 'ページ名アクセント';
+$lang['deaccent']              = 'ページ名の変換方法';
 $lang['useheading']            = '最初の見出しをページ名とする';
 $lang['sneaky_index']          = 'デフォルトでは索引にすべての名前空間を表示しますが、この機能はユーザーに閲覧権限のない名前空間を非表示にします。ただし、閲覧が可能な副名前空間まで表示されなくなるため、ACLの設定が適正でない場合は索引機能が使えなくなる場合があります。';
 $lang['hidepages']             = '検索、サイトマップ、その他の自動インデックスの結果に表示しないページ（Regex）';
@@ -146,6 +146,10 @@ $lang['renderer_xhtml']        = 'Wikiの出力（xhtml）にレンダラーを
 $lang['renderer__core']        = '%s （Dokuwikiコア）';
 $lang['renderer__plugin']      = '%s （プラグイン）';
 $lang['dnslookups']            = 'ページを編集しているユーザーのIPアドレスからホスト名を逆引きする。利用できるDNSサーバーがない、あるいはこの機能が不要な場合にはオフにします。';
+$lang['jquerycdn']             = 'コンテンツ・デリバリー・ネットワーク (CDN) の選択：jQuery と jQuery UI スクリプトを CDN からロードさせる場合には、追加的な HTTP リクエストが発生しますが、ブラウザキャッシュが使用されるため、表示速度の向上が期待できます。';
+$lang['jquerycdn_o_0']         = 'CDN を使用しない（または利用できない）';
+$lang['jquerycdn_o_jquery']    = 'CDN: code.jquery.com を使用';
+$lang['jquerycdn_o_cdnjs']     = 'CDN: cdnjs.com を使用';
 $lang['proxy____host']         = 'プロキシ - サーバー名';
 $lang['proxy____port']         = 'プロキシ - ポート';
 $lang['proxy____user']         = 'プロキシ - ユーザー名';
@@ -165,9 +169,9 @@ $lang['typography_o_2']        = 'すべての引用符（動作しない場合
 $lang['userewrite_o_0']        = '使用しない';
 $lang['userewrite_o_1']        = '.htaccess';
 $lang['userewrite_o_2']        = 'DokuWikiによる設定';
-$lang['deaccent_o_0']          = '指定しない';
-$lang['deaccent_o_1']          = 'アクセントを除去';
-$lang['deaccent_o_2']          = 'ローマナイズ';
+$lang['deaccent_o_0']          = '変換しない';
+$lang['deaccent_o_1']          = 'アクセント付きの文字を変換する';
+$lang['deaccent_o_2']          = 'ローマ字化';
 $lang['gdlib_o_0']             = 'GDを利用できません';
 $lang['gdlib_o_1']             = 'バージョン 1.x';
 $lang['gdlib_o_2']             = '自動検出';
