@@ -1,14 +1,27 @@
 <?php
+
 /**
- * Spanish language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
  * @author Oscar M. Lage <r0sk10@gmail.com>
  * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
- * @author oliver@samera.com.py
+ * @author oliver <oliver@samera.com.py>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Manuel Meco <manuel.meco@gmail.com>
  * @author VictorCastelan <victorcastelan@gmail.com>
- * @author Jordan Mero  hack.jord@gmail.com
+ * @author Jordan Mero <hack.jord@gmail.com>
+ * @author Felipe Martinez <metalmartinez@gmail.com>
+ * @author Javier Aranda <internet@javierav.com>
+ * @author Zerial <fernando@zerial.org>
+ * @author Marvin Ortega <maty1206@maryanlinux.com>
+ * @author Daniel Castro Alvarado <dancas2@gmail.com>
+ * @author Fernando J. Gómez <fjgomez@gmail.com>
+ * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
+ * @author emezeta <emezeta@infoprimo.com>
+ * @author Oscar Ciudad <oscar@jacho.net>
+ * @author Ruben Figols <ruben.figols@gmail.com>
+ * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
+ * @author Mercè López <mercelz@gmail.com>
  */
 $lang['menu']                  = 'Restaurador';
 $lang['filter']                = 'Buscar páginas con spam';
@@ -17,5 +30,5 @@ $lang['reverted']              = '%s ha restaurado la revisión %s';
 $lang['removed']               = '%s borrado';
 $lang['revstart']              = 'El proceso de restaurado ha comenzado. Puede llevar bastante tiempo. Si el script se para antes de acabar, deberías restaurar cadenas más pequeñas.';
 $lang['revstop']               = 'El proceso de restaurado ha finalizado satisfactoriamente.';
-$lang['note1']                 = 'Nota: la búsqueda diferencia mayúsculas de minúsculas (case sensitive)';
+$lang['note1']                 = 'Nota: la búsqueda diferencia entre mayúsculas y minúsculas.';
 $lang['note2']                 = 'Nota: la página será restaurada a la última versión que no tenga el término de spam dado <em>%s</em>.';
