@@ -26,7 +26,6 @@ $showSidebar = $hasSidebar && ($ACT=='show');
 </head>
 
 <body>
-    <!--[if lte IE 7 ]><div id="IE7"><![endif]--><!--[if IE 8 ]><div id="IE8"><![endif]-->
     <div id="dokuwiki__site"><div id="dokuwiki__top" class="site <?php echo tpl_classes(); ?> <?php
         echo ($showSidebar) ? 'showSidebar' : ''; ?> <?php echo ($hasSidebar) ? 'hasSidebar' : ''; ?>">
 
@@ -36,19 +35,20 @@ $showSidebar = $hasSidebar && ($ACT=='show');
 
             <?php if($showSidebar): ?>
                 <!-- ********** ASIDE ********** -->
-                <div id="dokuwiki__aside"><div class="pad include group">
+                <div id="dokuwiki__aside"><div class="pad aside include group">
                     <h3 class="toggle"><?php echo $lang['sidebar'] ?></h3>
-                    <div class="content">
+                    <div class="content"><div class="group">
                         <?php tpl_flush() ?>
                         <?php tpl_includeFile('sidebarheader.html') ?>
-                        <?php tpl_include_page($conf['sidebar'], 1, 1) ?>
+                        <?php tpl_include_page($conf['sidebar'], true, true) ?>
                         <?php tpl_includeFile('sidebarfooter.html') ?>
-                    </div>
+                    </div></div>
                 </div></div><!-- /aside -->
             <?php endif; ?>
 
             <!-- ********** CONTENT ********** -->
             <div id="dokuwiki__content"><div class="pad group">
+                <?php html_msgarea() ?>
 
                 <div class="pageId"><span><?php echo hsc($ID) ?></span></div>
 
@@ -73,28 +73,7 @@ $showSidebar = $hasSidebar && ($ACT=='show');
                 <h3 class="a11y"><?php echo $lang['page_tools']; ?></h3>
                 <div class="tools">
                     <ul>
-                        <?php
-                            $data = array(
-                                'view'  => 'main',
-                                'items' => array(
-                                    'edit'      => tpl_action('edit',      1, 'li', 1, '<span>', '</span>'),
-                                    'revert'    => tpl_action('revert',    1, 'li', 1, '<span>', '</span>'),
-                                    'revisions' => tpl_action('revisions', 1, 'li', 1, '<span>', '</span>'),
-                                    'backlink'  => tpl_action('backlink',  1, 'li', 1, '<span>', '</span>'),
-                                    'subscribe' => tpl_action('subscribe', 1, 'li', 1, '<span>', '</span>'),
-                                    'top'       => tpl_action('top',       1, 'li', 1, '<span>', '</span>')
-                                )
-                            );
-
-                            // the page tools can be amended through a custom plugin hook
-                            $evt = new Doku_Event('TEMPLATE_PAGETOOLS_DISPLAY', $data);
-                            if($evt->advise_before()){
-                                foreach($evt->data['items'] as $k => $html) echo $html;
-                            }
-                            $evt->advise_after();
-                            unset($data);
-                            unset($evt);
-                        ?>
+                        <?php echo (new \dokuwiki\Menu\PageMenu())->getListItems(); ?>
                     </ul>
                 </div>
             </div>
@@ -105,6 +84,5 @@ $showSidebar = $hasSidebar && ($ACT=='show');
 
     <div class="no"><?php tpl_indexerWebBug() /* provide DokuWiki housekeeping, required in all templates */ ?></div>
     <div id="screen__mode" class="no"></div><?php /* helper to detect CSS media query in script.js */ ?>
-    <!--[if ( lte IE 7 | IE 8 ) ]></div><![endif]-->
 </body>
 </html>
